@@ -1,4 +1,4 @@
-# $Header: /cvsroot/tikiwiki/tiki/fixperms.sh,v 1.1.2.10 2008/02/07 21:45:02 lphuberdeau Exp $
+# $Header: /cvsroot/tikiwiki/tiki/fixperms.sh,v 1.9.2.2 2008-02-07 21:59:14 lphuberdeau Exp $
 
 # Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 # All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -7,7 +7,7 @@
 # This file is a replacement for setup.sh
 # in test in 1.9 version
 
-DIRS="backups db dump img/wiki img/wiki_up img/trackers modules/cache temp temp/cache templates_c templates styles maps whelp mods files"
+DIRS="backups db dump img/wiki img/wiki_up img/trackers modules/cache temp temp/cache templates_c templates styles maps whelp mods files tiki_tests/tests"
 
 if [ -d 'lib/Galaxia' ]; then
 	DIRS=$DIRS" lib/Galaxia/processes"
@@ -64,6 +64,7 @@ or
 2- If you press enter to continue, you will probably get some error messages but it (the script) will 
 still fix what it can according to the permissions of your user. This script will now ask you some 
 questions. If you don't know what to answer, just press enter to each question (to use default value)"
+	
 		read 
 		AUSER=$USER
 	fi
@@ -150,6 +151,7 @@ or
 2- If you press enter to continue, you will probably get some error messages but it (the script) will 
 still fix what it can according to the permissions of your user. This script will now ask you some 
 questions. If you don't know what to answer, just press enter to each question (to use default value)"
+
 		read 
 		echo -n "Open global perms ..."
 		find . -type d -exec chmod 777 {} \;
