@@ -1,19 +1,13 @@
 <?php
 /** \file
- * $Header: /cvsroot/tikiwiki/tiki/lib/debug/debugger.php,v 1.6.4.1 2008/02/21 19:10:04 marclaporte Exp $
+ * $Id: /cvsroot/tikiwiki/tiki/lib/debug/debugger.php,v 1.6 2004-01-15 21:55:40 mose Exp $
  *
- * \brief Tiki internal debugger
+ * \brief Tiki internal debugger 
  *
  * \author zaufi <zaufi@sendmail.ru>
  *
  */
 
-//this script may only be included - so its better to die if called directly.
-if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
-  header("location: index.php");
-  exit;
-}
-
 require_once('lib/debug/debugger-common.php');
 
 /// Path to debugger's external commands
@@ -79,7 +73,7 @@ class Debugger extends ResultType
 	        else
 	          $this->commands[$this->noname_cmd_idx++] = $obj;
         }
-        // else
+        // else 
           // TODO: Must issue a warnig?
       }
       // Must issue a warning?
@@ -126,7 +120,7 @@ class Debugger extends ResultType
         {
           $result["action"] = 'list';
           // No. This is along help on command line. Append my help...
-          $result[0][] = array('cmd' => 'help',
+          $result[0][] = array('cmd' => 'help', 
             'description'=>'Display list of commands or help for specified command (<code>help print</code> for example)');
           foreach ($this->commands as $cmdobj)
             if (strlen(trim($cmdobj->name())) > 0)
@@ -171,7 +165,7 @@ class Debugger extends ResultType
   {
     $this->dmsgs[] = array("timestamp" => time(), "msg" => $s);
   }
-  /**
+  /** 
    * \brief Dump variable (global) into string (errors aware function)
    * \todo Need to rename all local variables to smth realy unique
    *       (smth that user never guess and try to print :)
