@@ -1,5 +1,5 @@
 <?php
-// $Header: /cvsroot/tikiwiki/tiki/lib/imagegals/imagegallib.php,v 1.45.2.43 2008/01/28 17:36:26 mose Exp $
+// $Id: /cvsroot/tikiwiki/tiki/lib/imagegals/imagegallib.php,v 1.97.2.4 2008-03-06 19:45:42 sampaioprimo Exp $
 
 //this script may only be included - so its better to die if called directly.
 if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
@@ -9,12 +9,9 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
 
 class ImageGalsLib extends TikiLib {
 	function ImageGalsLib($db) {
-		# this is probably uneeded now
-		if (!$db) {
-			die ("Invalid db object passed to ImagegalLib constructor");
-		}
+		global $prefs;
 
-		$this->db = $db;
+		$this->TikiLib($db);
 		$exts=get_loaded_extensions();
 
 		// Which GD Version do we have?
@@ -52,7 +49,8 @@ class ImageGalsLib extends TikiLib {
 
 		// Do we have the imagick PECL module?
 		// Module can be downloaded at http://pecl.php.net/package/imagick
-		if (in_array('imagick',$exts)) {
+		// Also check on 'imagick_rotate' function because the first check may detect imagick 2.x which has a completely different API
+		if ( in_array('imagick',$exts) && function_exists('imagick_rotate') ) {
 			$this->haveimagick = true;
 		} else {
 			$this->haveimagick = false;
@@ -61,7 +59,13 @@ class ImageGalsLib extends TikiLib {
 		//what shall we use?
 
 		//$this->uselib = "gd";
-		$this->uselib = $this->get_preference('gal_use_lib', 'gd');
+		$this->uselib = $prefs['gal_use_lib'];
+
+		//Fallback to GD
+		if ($this->uselib == "imagick" && $this->haveimagick == false) {
+			$this->uselib = "gd";
+			$this->set_preference('gal_use_lib', 'gd');
+		}
 
 		if ($this->uselib == "imagick") {
 			$this->canrotate = true;
@@ -69,12 +73,6 @@ class ImageGalsLib extends TikiLib {
 			$this->canrotate = false;
 		}
 
-		//Fallback to GD
-		if ($this->uselib == "imagick" && $this->haveimagick == false) {
-			$this->uselib = "gd";
-
-			$this->set_preference('gal_use_lib', 'gd');
-		}
 
 		// get variables to determine if we can upload and how many data
 		// we can upload
@@ -341,6 +339,8 @@ class ImageGalsLib extends TikiLib {
 
 		$newx = round($this->xsize / $tscale);
 		$newy = round($this->ysize / $tscale);
+		if ($newx > $this->xsize && $newy > $this->ysize)
+			return true;
 		return $this->resizeImage($newx, $newy);
 	}
 
@@ -418,12 +418,8 @@ class ImageGalsLib extends TikiLib {
 
 	// Batch image uploads todo
 	function process_batch_image_upload($galleryId, $file, $user) {
-		global $gal_match_regex;
+		global $prefs;
 
-		global $gal_nmatch_regex;
-		global $gal_use_db;
-		global $gal_use_dir;
-		global $tmpDir;
 		$numimages = 0;
 		include_once ('lib/pclzip.lib.php');
 		$archive = new PclZip($file);
@@ -442,18 +438,18 @@ class ImageGalsLib extends TikiLib {
 
 				$upl = 1;
 
-				if (!empty($gal_match_regex)) {
-					if (!preg_match("/$gal_match_regex/", $file, $reqs))
+				if (!empty($prefs['gal_match_regex'])) {
+					if (!preg_match('/'.$prefs['gal_match_regex'].'/', $file, $reqs))
 						$upl = 0;
 				}
 
-				if (!empty($gal_nmatch_regex)) {
-					if (preg_match("/$gal_nmatch_regex/", $file, $reqs))
+				if (!empty($prefs['gal_nmatch_regex'])) {
+					if (preg_match('/'.$prefs['gal_nmatch_regex'].'/', $file, $reqs))
 						$upl = 0;
 				}
 				//extract file
 				$archive->extractByIndex($ziplist["$i"]["index"],
-					$tmpDir, dirname($file)); //extract and remove (dangerous) pathname
+					$prefs['tmpDir'], dirname($file)); //extract and remove (dangerous) pathname
 				$file = basename($file);
 
 				//unset variables
@@ -462,13 +458,13 @@ class ImageGalsLib extends TikiLib {
 				unset ($this->ysize);
 
 				//determine filetype and dimensions
-				$this->getfileinfo($tmpDir . "/" . $file);
+				$this->getfileinfo($prefs['tmpDir'] . "/" . $file);
 				
 				$foo=explode(".",$file);
 				$exp=end($foo);
 				// read image and delete it after
-				$this->readimagefromfile($tmpDir . "/" . $file);
-				unlink ($tmpDir . "/" . $file);
+				$this->readimagefromfile($prefs['tmpDir'] . "/" . $file);
+				unlink ($prefs['tmpDir'] . "/" . $file);
 
 				if ($this->issupported($exp)) {
 					// convert to handle
@@ -497,18 +493,14 @@ class ImageGalsLib extends TikiLib {
 	}
 
 	function add_image_hit($id) {
-		global $count_admin_pvs;
+		global $prefs, $user;
 
-		global $user;
-
-		if ($count_admin_pvs == 'y' || $user != 'admin') {
+		if ($prefs['count_admin_pvs'] == 'y' || $user != 'admin') {
 			$query = "update `tiki_images` set `hits`=`hits`+1 where `imageId`=?";
-
 			$result = $this->query($query,array((int)$id));
 		}
 
-		global $feature_score;
-		if ($feature_score == 'y') {
+		if ($prefs['feature_score'] == 'y') {
 		    $this->score_event($user, 'igallery_see_img', $id);
 		    $query = "select `user` from `tiki_images` where `imageId`=?";
 		    $owner = $this->getOne($query, array((int)$id));
@@ -519,18 +511,15 @@ class ImageGalsLib extends TikiLib {
 	}
 
 	function add_gallery_hit($id) {
-		global $count_admin_pvs;
+		global $prefs, $user;
 
-		global $user;
-
-		if ($count_admin_pvs == 'y' || $user != 'admin') {
+		if ($prefs['count_admin_pvs'] == 'y' || $user != 'admin') {
 			$query = "update `tiki_galleries` set `hits`=`hits`+1 where `galleryId`=?";
 
 			$result = $this->query($query,array((int) $id));
 		}
 
-		global $feature_score;
-		if ($feature_score == 'y') {
+		if ($prefs['feature_score'] == 'y') {
 		    $this->score_event($user, 'igallery_see', $id);
 		    $query = "select `user` from `tiki_galleries` where `galleryId`=?";
 		    $owner = $this->getOne($query, array((int)$id));
@@ -578,14 +567,12 @@ class ImageGalsLib extends TikiLib {
 	}
 
 	function store_image_data($overwrite = false) {
-		global $gal_use_dir;
-
-		global $gal_use_db;
+		global $prefs;
 
 		$size = strlen($this->image);
 		$fhash = "";
 
-		if ($gal_use_db == 'y') {
+		if ($prefs['gal_use_db'] == 'y') {
 			// Prepare to store data in database
 		} else {
 			// Store data in directory
@@ -611,7 +598,7 @@ class ImageGalsLib extends TikiLib {
 			}
 
 			$fhash = $this->path . $ext; //Path+extension
-			@$fw = fopen($gal_use_dir . $fhash, "wb");
+			@$fw = fopen($prefs['gal_use_dir'] . $fhash, "wb");
 
 			if (!$fw) {
 				return false;
@@ -642,12 +629,12 @@ class ImageGalsLib extends TikiLib {
 			where
 			`imageId`=? and `type`=? and
 			`xsize`=? and `ysize`=?";
-			 $bindvars=array($this->filetype,$this->filename,($gal_use_db == 'y')?$this->image:'',(int)$size,(int)$this->xsize,(int)$this->ysize,(int)$this->imageId,$this->type,(int)$this->oldxsize,(int)$this->oldysize);
+			 $bindvars=array($this->filetype,$this->filename,($prefs['gal_use_db'] == 'y')?$this->image:'',(int)$size,(int)$this->xsize,(int)$this->ysize,(int)$this->imageId,$this->type,(int)$this->oldxsize,(int)$this->oldysize);
 		} else {
 			$query = "insert into `tiki_images_data`(`imageId`,`xsize`,`ysize`,
                                 `type`,`filesize`,`filetype`,`filename`,`data`)
                         values (?,?,?,?,?,?,?,?)";
-			$bindvars=array((int)$this->imageId,(int)$this->xsize,(int)$this->ysize,$this->type,(int)$size,$this->filetype,$this->filename,($gal_use_db == 'y')?$this->image:'');
+			$bindvars=array((int)$this->imageId,(int)$this->xsize,(int)$this->ysize,$this->type,(int)$size,$this->filetype,$this->filename,($prefs['gal_use_db'] == 'y')?$this->image:'');
 		}
 
 		$result = $this->query($query,$bindvars);
@@ -655,7 +642,9 @@ class ImageGalsLib extends TikiLib {
 	}
 
 	function rebuild_image($imageid, $itype, $xsize, $ysize=0) {
-		$galid = $this->get_gallery_from_image($imageid);
+	        global $prefs;
+	        
+	        $galid = $this->get_gallery_from_image($imageid);
 		if($ysize==0) {
 			$ysize=$xsize;
 		}
@@ -666,18 +655,27 @@ class ImageGalsLib extends TikiLib {
 
 		//if it is a scaled image, test the gallery settings
 		if ($itype == 's') {
-			$scaleinfo = $this->get_gallery_scale_info($galid);
-
 			$hasscale = false;
 
-			while (list($num, $sci) = each($scaleinfo)) {
+			if ($prefs["preset_galleries_info"] == 'y' && $prefs["scaleSizeGalleries"] > 0) {
+			    $scaleinfo = $prefs["scaleSizeGalleries"];
+			    if ((($scaleinfo == $xsize) && ($scaleinfo >= $ysize)) || (($scaleinfo == $ysize) && ($scaleinfo >= $xsize))) {
+				$hasscale = true;
+				$newx = $scaleinfo;
+				$newy = $scaleinfo;
+			    }
+			} else {
+			    $scaleinfo = $this->get_gallery_scale_info($galid);
+			    while (list($num, $sci) = each($scaleinfo)) {
 				if ((($sci['scale'] == $xsize) && ($sci['scale'] >= $ysize)) || 
 				    (($sci['scale'] == $ysize) && ($sci['scale'] >= $xsize))) {
-					$hasscale = true;
-
-					$newx = $sci['scale'];
-					$newy = $sci['scale'];
+				    $hasscale = true;
+				    
+				    $newx = $sci['scale'];
+				    $newy = $sci['scale'];
 				}
+			    }
+			    
 			}
 
 			if (!$hasscale)
@@ -685,8 +683,6 @@ class ImageGalsLib extends TikiLib {
 		}
 
 		// now we can start rebuilding the image
-		global $gal_use_dir;
-		global $gal_use_db;
 		//if(!function_exists("ImageCreateFromString")) return false;
 		#get image and other infos
 		$this->get_image($imageid);
@@ -719,8 +715,8 @@ class ImageGalsLib extends TikiLib {
 		$filename = $this->filename; // filename of original image
 		$this->type = $itype;
 
-		//store
-		$this->store_image_data();
+		//store (needs overwrite param to be true to update, not create new)
+		$this->store_image_data(true);
 
 		//return new size
 		$newsize["xsize"] = $this->xsize;
@@ -729,9 +725,7 @@ class ImageGalsLib extends TikiLib {
 	}
 
 	function rebuild_thumbnails($galleryId) {
-		global $gal_use_dir;
-
-		global $gal_use_db;
+		global $prefs;
 
 		// rewritten by flo
 		$query = "select `imageId`, `path` from `tiki_images` where `galleryId`=?";
@@ -743,7 +737,7 @@ class ImageGalsLib extends TikiLib {
 			$result2 = $this->query($query2,array((int)$res["imageId"],'t'));
 
 			if (strlen($res["path"]) > 0) {
-				$ftn = $gal_use_dir . $res["path"] . ".thumb";
+				$ftn = $prefs['gal_use_dir'] . $res["path"] . ".thumb";
 
 				if (file_exists($ftn)) {
 					unlink ($ftn);
@@ -754,78 +748,104 @@ class ImageGalsLib extends TikiLib {
 		return true;
 	}
 
-  function rebuild_scales($galleryId, $imageId = -1) {
-    // doesn't really rebuild, it deletes the scales and thumbs for 
-    // automatic rebuild
-    // give either a galleryId for rebuild complete gallery or
-    // a imageId for a image rebuild
-    global $gal_use_dir;
-    if ($imageId == -1) {
-      //gallery mode
-      //mysql does'nt have subqueries. Bad.
+	function rebuild_scales($galleryId, $imageId = -1) {
+		// doesn't really rebuild, it deletes the scales and thumbs for 
+		// automatic rebuild
+		// give either a galleryId for rebuild complete gallery or
+		// a imageId for a image rebuild
+    global $prefs;
+		if ($imageId == -1) {
+			//gallery mode
+			//mysql does'nt have subqueries. Bad.
       $bindvars=array();
-      $query1 = "select `imageId`,`path` from `tiki_images`";
+			$query1 = "select `imageId`,`path` from `tiki_images`";
       if($galleryId>-1) { // if galleryid == -1 then all galleries
         $query1 .= ' where `galleryId`=?';
         $bindvars=array((int)$galleryId);
       }
 
-      $result1 = $this->query($query1,$bindvars);
+			$result1 = $this->query($query1,$bindvars);
 
-      while ($res = $result1->fetchRow()) {
-        $query2 = 'select `xsize`,`ysize`,`type` from `tiki_images_data` where `imageId`=? and not (`type`=?)';
-        $query3 = "delete from `tiki_images_data` where `imageId`=? and not (`type`=?)";
+			while ($res = $result1->fetchRow()) {
+			  $query2 = 'select `xsize`,`ysize`,`type` from `tiki_images_data` where `imageId`=? and not (`type`=?)';
+				$query3 = "delete from `tiki_images_data` where `imageId`=? and not (`type`=?)";
         $bindvars2=array((int)$res["imageId"],'o');
 
-        $result2 = $this->query($query2,$bindvars2);
+				$result2 = $this->query($query2,$bindvars2);
         while($res2=$result2->fetchRow()) {
-          if(!empty($res['path'])) {
-            if($res2['type']=='s') { $ext = ".scaled_" . $res2['xsize'] . "x" . $res2['ysize'];}
-            if($res2['type']=='t') { $ext = ".thumb";}
+				  if(!empty($res['path'])) {
+				    if($res2['type']=='s') { $ext = ".scaled_" . $res2['xsize'] . "x" . $res2['ysize'];}
+				    if($res2['type']=='t') { $ext = ".thumb";}
             if($res2['type']=='s' || $res2['type']=='t') { // in case we add other types later
-              @unlink($gal_use_dir.$res['path'].$ext );
+              @unlink($prefs['gal_use_dir'].$res['path'].$ext );
             }
           }
-        }
+				}
         // delete images_data entries
-        $result3 = $this->query($query3,$bindvars2);
-      }
-    } else {
-      //image mode
-      $query = "delete from `tiki_images_data` where `ImageId`=? and not `type`=?";
+				$result3 = $this->query($query3,$bindvars2);
+			}
+		} else {
+			//image mode
+			$query = "delete from `tiki_images_data` where `ImageId`=? and not `type`=?";
 
-      $result = $this->query($query,array((int)$ImageId,'o'));
-    }
-  }
+			$result = $this->query($query,array((int)$ImageId,'o'));
+		}
+	}
 
-	function edit_image($id, $name, $description,$lat=NULL,$lon=NULL) {
+	function edit_image($id, $name, $description, $lat=NULL, $lon=NULL, $file=NULL) {
+		global $prefs;
 		$name = strip_tags($name);
 
 		$description = strip_tags($description);
 		$query = "update `tiki_images` set `name`=?, `description`=?, `lat`=?, `lon`=? where `imageId` = ?";
 		$result = $this->query($query,array($name,$description,$lat,$lon,(int)$id));
+		if (!empty($file) && !empty($file['name'])) {
+			if (!is_uploaded_file($file['tmp_name']) || !($fp = fopen($file['tmp_name'], "rb")))
+				return false;
+			$data =  fread($fp, $file['size']);
+			$etag = md5($data);
+			fclose($fp);
+			if ($prefs['gal_use_db'] == 'y') {
+				$query = "update `tiki_images_data` set `data`=?, `etag`=?, `filename`=? where `imageId` = ? and `type`=?";
+				$result = $this->query($query,array($data, $etag, $file['name'], (int)$id, 'o'));
+			} else {
+				$query = "select `path` from `tiki_images` where `imageId`=?";
+				$path = $this->getOne($query, $id);
+				if (!move_uploaded_file($file['tmp_name'], $prefs['gal_use_dir'].$path)) {
+					return false;
+				}
+				$query = "update `tiki_images_data` set `etag`=?,`filename`=? where `imageId` = ? and `type`=?";
+				$result = $this->query($query,array($etag, $file['name'], (int)$id, 'o'));
+			}
+			$query = "delete from `tiki_images_data` where `imageId`=? and `type`!=?";
+			$result = $this->query($query, array((int)$id, 'o'));
+		}
+
+		if ( $prefs['feature_search'] == 'y' && $prefs['feature_search_fulltext'] != 'y' && $prefs['search_refresh_index_mode'] == 'normal' ) {
+			require_once('lib/search/refresh-functions.php');
+			refresh_index('images', $id);
+		}
+
 		return true;
 	}
 
 	function insert_image($galleryId, $name, $description, $filename, $filetype, &$data, $size, $xsize, $ysize, $user, $t_data, $t_type ,$lat=NULL, $lon=NULL, $gal_info=NULL) {
-		global $gal_use_db;
+		global $prefs;
 
-		global $gal_use_dir;
 		$name = strip_tags($name);
 		$description = strip_tags($description);
 		if ($t_data && is_string($t_data)) {
 			$t_data = array('data' => $t_data, 'xsize' => 0, 'ysize' => 0);
 		}
-		$now = date("U");
 		$path = '';
 
-		if ($gal_use_db == 'y') {
+		if ($prefs['gal_use_db'] == 'y') {
 			// Prepare to store data in database
 		} else {
 			// Store data in directory
 			$fhash = md5(uniqid($filename));
 
-			@$fw = fopen($gal_use_dir . $fhash, "wb");
+			@$fw = fopen($prefs['gal_use_dir'] . $fhash, "wb");
 
 			if (!$fw) {
 				return false;
@@ -835,7 +855,7 @@ class ImageGalsLib extends TikiLib {
 			fclose ($fw);
 
 			if ($t_data) {
-				@$fw = fopen($gal_use_dir . $fhash . '.thumb', "wb");
+				@$fw = fopen($prefs['gal_use_dir'] . $fhash . '.thumb', "wb");
 
 				if (!$fw) {
 					return false;
@@ -852,9 +872,9 @@ class ImageGalsLib extends TikiLib {
 
 		$query = "insert into `tiki_images`(`galleryId`,`name`,`description`,`user`,`created`,`hits`,`path`,`lat`,`lon`)
                           values(?,?,?,?,?,?,?,?,?)";
-		$result = $this->query($query,array((int)$galleryId,$name,$description,$user,(int)$now,0,$path,$lat,$lon));
+		$result = $this->query($query,array((int)$galleryId,$name,$description,$user,(int)$this->now,0,$path,$lat,$lon));
 		$query = "select max(`imageId`) from `tiki_images` where `created`=?";
-		$imageId = $this->getOne($query,array((int)$now));
+		$imageId = $this->getOne($query,array((int)$this->now));
 		// insert data
 		$this->blob_encode($data);
 		$query = "insert into `tiki_images_data`(`imageId`,`xsize`,`ysize`,
@@ -873,21 +893,31 @@ class ImageGalsLib extends TikiLib {
 		}
 
 		$query = "update `tiki_galleries` set `lastModif`=? where `galleryId`=?";
-		$result = $this->query($query,array((int)$now,(int)$galleryId));
+		$result = $this->query($query,array((int)$this->now,(int)$galleryId));
 
-		global $feature_score;
-		if ($feature_score == 'y') {
+		global $prefs;
+		if ($prefs['feature_score'] == 'y') {
 		    $this->score_event($user, 'igallery_new_img');
 		}
 
+		if ($prefs['feature_actionlog'] == 'y') {
+			global $logslib; include_once('lib/logs/logslib.php');
+			$logslib->add_action('Uploaded', $galleryId, 'image gallery', 'imageId='.$imageId);
+		}
+
+		if ( $prefs['feature_search'] == 'y' && $prefs['feature_search_fulltext'] != 'y' && $prefs['search_refresh_index_mode'] == 'normal' ) {
+			require_once('lib/search/refresh-functions.php');
+			refresh_index('images', $imageId);
+		}
+		
 		$this->notify($imageId, $galleryId, $name, $filename, $description, isset($gal_info['name'])?$gal_info['name']: '', $user);
 
 		return $imageId;
 	}
 
 	function notify($imageId, $galleryId, $name, $filename, $description, $galleryName, $user) {
-		global $feature_user_watches;
-		if ($feature_user_watches == 'y') {
+		global $prefs;
+		if ($prefs['feature_user_watches'] == 'y') {
 			include_once('lib/notifications/notificationemaillib.php');
 			global $smarty, $tikilib;
 			$nots = $this->get_event_watches('image_gallery_changed', $galleryId);
@@ -908,9 +938,8 @@ class ImageGalsLib extends TikiLib {
 
 	function rotate_image($id, $angle) {
 		//get image
-		global $gal_use_dir;
+		global $prefs;
 
-		global $gal_use_db;
 		$this->get_image($id);
 
 		$this->rotateimage($angle);
@@ -929,19 +958,19 @@ class ImageGalsLib extends TikiLib {
 	}
 
 	function remove_image($id) {
-		global $gal_use_dir;
+		global $prefs;
 
 		$path = $this->getOne("select `path` from `tiki_images` where `imageId`=?",array($id));
 
 		if ($path) {
-			@unlink ($gal_use_dir . $path);
+			@unlink ($prefs['gal_use_dir'] . $path);
 
-			@unlink ($gal_use_dir . $path . '.thumb');
+			@unlink ($prefs['gal_use_dir'] . $path . '.thumb');
 		  // remove scaled images
 		  $query = "select i.`path`, d.`xsize`, d.`ysize` from `tiki_images` i, `tiki_images_data` d where i.`imageId`=d.`imageId` and i.`imageId`=? and d.`type`=?";
 		  $result=$this->query($query,array($id,'s'));
 		  while($res = $result->fetchRow()) {
-                    @unlink ($gal_use_dir . $path . '.scaled_'.$res['xsize'].'x'.$res['ysize']);
+                    @unlink ($prefs['gal_use_dir'] . $path . '.scaled_'.$res['xsize'].'x'.$res['ysize']);
 		  }
 		}
 
@@ -1133,6 +1162,55 @@ class ImageGalsLib extends TikiLib {
 			return($imageId);
 	}
 
+	function get_prev_and_next_image($sort_mode, $find, $imageId, $galleryId = -1) {
+
+		if ($find) {
+			$findesc = '%' . $find . '%';
+
+			$mid = " and (`name` like ? or `description` like ?)";
+			$bindvars=array('o',$findesc,$findesc);
+		} else {
+			$mid = "";
+			$bindvars=array('o');
+		}
+
+		$midcant = "";
+		$cantvars=array();
+
+		if ($galleryId != -1 && is_numeric($galleryId)) {
+			$mid .= " and i.`galleryId`=? ";
+			$bindvars[]=(int)$galleryId;
+			$midcant = "where `galleryId`=? ";
+			$cantvars[]=(int)$galleryId;
+		}
+
+		$query = "select i.`imageId`
+                from `tiki_images` i , `tiki_images_data` d
+                 where i.`imageId`=d.`imageId`
+                 and d.`type`=?
+                $mid
+                order by ";
+        /* if sort by filesize while browsing images it needs to be read from tiki_image_data table */
+		if ($sort_mode == 'filesize_asc' || $sort_mode == 'filesize_desc') {
+			$query.='d.';
+		} else {
+			$query.='i.';
+		}
+        $query .= $this->convert_sortmode($sort_mode);
+		$result = $this->query($query,$bindvars);
+		$prev=-1; $next=0; $tmpid=0;
+		while ($res = $result->fetchRow()) {
+		        if ($imageId == $res['imageId']) {
+		                $prev=$tmpid;
+		        } else if ($prev >= 0) { // $prev is set, so, this one is the next
+		                $next=$res['imageId'];
+		                break;
+		        }
+		        $tmpid=$res['imageId'];
+		}
+		return array('prev' => ($prev > 0 ? $prev : 0), 'next' => $next);
+	}
+
 	function get_first_image($sort_mode, $find, $galleryId = -1) {
 
 		if ($find) {
@@ -1223,12 +1301,13 @@ class ImageGalsLib extends TikiLib {
 	if ($cant) {
 	    $pick = rand(0, $cant - 1);
 
-	    $query = "select `imageId` ,`galleryId`,`name` from `tiki_images` $whgal";
+	    $query = "select `imageId` ,`description`, `galleryId`,`name` from `tiki_images` $whgal";
 	    $result = $this->query($query,$bindvars,1,$pick);
 	    $res = $result->fetchRow();
 	    $ret["galleryId"] = $res["galleryId"];
 	    $ret["imageId"] = $res["imageId"];
 	    $ret["name"] = $res["name"];
+	    $ret["description"] = $res["description"];
 	    $query = "select `name`  from `tiki_galleries` where `galleryId` = ?";
 	    $ret["gallery"] = $this->getOne($query,array((int)$res["galleryId"]));
 	} else {
@@ -1291,45 +1370,13 @@ class ImageGalsLib extends TikiLib {
 	    $cant = $this->getOne($query_cant,$bindvars);
 	    $ret = array();
 
+	    global $prefs, $userlib, $user, $tiki_p_admin;
 	    while ($res = $result->fetchRow()) {
-
-		$add = TRUE;
-		global $feature_categories;
-		global $userlib;
-		global $user;
-		global $tiki_p_admin;
-
-		if ($tiki_p_admin != 'y' && $userlib->object_has_one_permission($res['galleryId'], 'image gallery')) {
-		    // gallery permissions override category permissions
-		    if (!$userlib->object_has_permission($user, $res['galleryId'], 'image gallery', 'tiki_p_view_image_gallery')) {
-			$add = FALSE;
-		    }
-		} elseif ($tiki_p_admin != 'y' && $feature_categories == 'y') {
-		    // no forum permissions so now we check category permissions
-		    global $categlib;
-		    if (!is_object($categlib)) {
-			include_once('lib/categories/categlib.php');
-		    }
-		    unset($tiki_p_view_categories); // unset this var in case it was set previously
-		    $perms_array = $categlib->get_object_categories_perms($user, 'image gallery', $res['galleryId']);
-		    if ($perms_array) {
-			$is_categorized = TRUE;
-			foreach ($perms_array as $perm => $value) {
-			    $$perm = $value;
+			$res['perms'] = $this->get_perm_object($res['galleryId'], 'image gallery', $res, false);
+			if ($res['perms']['tiki_p_view_image_gallery'] == 'y') {
+				$res['images'] = $this->getOne("select count(*) from `tiki_images` where `galleryId`=?",array($res['galleryId']));
+				$ret[] = $res;
 			}
-		    } else {
-			$is_categorized = FALSE;
-		    }
-
-		    if ($is_categorized && isset($tiki_p_view_categories) && $tiki_p_view_categories != 'y') {
-			$add = FALSE;
-		    }
-		}
-
-		if ($add) {
-		    $res['images'] = $this->getOne("select count(*) from `tiki_images` where `galleryId`=?",array($res['galleryId']));
-		    $ret[] = $res;
-		}
 	    }
 
 	    if ($old_sort_mode == 'images_asc') {
@@ -1514,9 +1561,8 @@ class ImageGalsLib extends TikiLib {
 
 	// Add an option to establish Image size (x,y)
 	function get_image($id, $itype = 'o', $xsize = 0, $ysize = 0) {
-		global $gal_use_db;
+		global $prefs;
 
-		global $gal_use_dir;
 		$mid = "";
 
 		if ($itype == 't') {
@@ -1547,7 +1593,7 @@ class ImageGalsLib extends TikiLib {
 
 		
 		
-		if(!@is_array($bindvars)) {
+		if(!isset($bindvars) || !is_array($bindvars)) {
 			$bindvars=array((int)$id,$itype);
 		}
 
@@ -1564,7 +1610,7 @@ class ImageGalsLib extends TikiLib {
 
 
 		$result = $this->query($query,$bindvars,1);
-		
+
 		if ($result===false || $result===null) {
 			die;
 		}
@@ -1592,7 +1638,12 @@ class ImageGalsLib extends TikiLib {
 		# build scaled images or thumb if not available
 		if ($itype != 'o' && !isset($this->imageId)) {
 			if ($newsize = $this->rebuild_image($id, $itype, $xsize, $ysize)) {
-				return $this->get_image($id, $itype, $newsize["xsize"], $newsize["ysize"]);
+				// removed because this causes endless recursion
+				//return $this->get_image($id, $itype, $newsize["xsize"], $newsize["ysize"]);
+
+				// Since the rescaled image is the one we want, we have to switch to its path and data
+				$res['path'] = $this->path;
+				$res['data'] = $this->image;
 			}
 		}
 
@@ -1621,10 +1672,10 @@ class ImageGalsLib extends TikiLib {
 
 			// If the image was a .gif then the thumbnail has 0 bytes if the thumbnail
 			// is empty then use the full image as thumbnail
-			//  if($ext==".thumb" && filesize($gal_use_dir.$res["path"].$ext)==0 ) {
+			//  if($ext==".thumb" && filesize($prefs['gal_use_dir'].$res["path"].$ext)==0 ) {
 			//   $ext='';
 			//}
-			$this->readimagefromfile($gal_use_dir . $res["path"] . $ext);
+			$this->readimagefromfile($prefs['gal_use_dir'] . $res["path"] . $ext);
 		} else {
 			$this->image = $res["data"];
 		}
@@ -1725,12 +1776,13 @@ class ImageGalsLib extends TikiLib {
 	}
 
 	function replace_gallery($galleryId, $name, $description, $theme, $user, $maxRows, $rowImages, $thumbSizeX, $thumbSizeY, $public, $visible = 'y', $sortorder='created', $sortdirection='desc', $galleryimage='first',$parentgallery=-1,$showname='y',$showimageid='n',$showdescription='n',$showcreated='n',$showuser='n',$showhits='y',$showxysize='y',$showfilesize='n',$showfilename='n',$defaultscale='o',$geographic	= 'n') {
+		global $prefs;
+
 		// if the user is admin or the user is the same user and the gallery exists then replace if not then
 		// create the gallary if the name is unused.
 		$name = strip_tags($name);
 
 		$description = strip_tags($description);
-		$now = date("U");
 
 		// check if the gallery already exists. if yes: do update, if no: update it
 		if ($galleryId<1)
@@ -1747,28 +1799,34 @@ class ImageGalsLib extends TikiLib {
 		`showfilename`=?,`defaultscale`=?, `user`=?
 	       	where `galleryId`=?";
 
-			$result = $this->query($query,array($name,$visible,$geographic,(int)$maxRows,(int)$rowImages,(int)$thumbSizeX,(int)$thumbSizeY,$description,$theme,(int)$now,$public,$sortorder,$sortdirection,$galleryimage,(int)$parentgallery,$showname,$showimageid,$showdescription,$showcreated,$showuser,$showhits,$showxysize,$showfilesize,$showfilename,$defaultscale,$user,(int)$galleryId));
+			$result = $this->query($query,array($name,$visible,$geographic,(int)$maxRows,(int)$rowImages,(int)$thumbSizeX,(int)$thumbSizeY,$description,$theme,(int)$this->now,$public,$sortorder,$sortdirection,$galleryimage,(int)$parentgallery,$showname,$showimageid,$showdescription,$showcreated,$showuser,$showhits,$showxysize,$showfilesize,$showfilename,$defaultscale,$user,(int)$galleryId));
 		} else {
 			// Create a new record
 			$query = "insert into `tiki_galleries`(`name`,`description`,`theme`,`created`,`user`,`lastModif`,`maxRows`,`rowImages`,`thumbSizeX`,`thumbSizeY`,`public`,`hits`,`visible`,`sortorder`,`sortdirection`,`galleryimage`,`parentgallery`,`showname`,`showimageid`,`showdescription`,`showcreated`,`showuser`,`showhits`,`showxysize`,`showfilesize`,`showfilename`,`defaultscale`,`geographic`) values (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
-			$bindvars=array($name,$description,$theme,(int) $now,$user,(int) $now,(int) $maxRows,(int) $rowImages,(int) $thumbSizeX,(int) $thumbSizeY,$public,0,$visible,$sortorder,$sortdirection,$galleryimage,(int)$parentgallery,$showname,$showimageid,$showdescription,$showcreated,$showuser,$showhits,$showxysize,$showfilesize,$showfilename,$defaultscale,$geographic);
+			$bindvars=array($name,$description,$theme,(int) $this->now,$user,(int) $this->now,(int) $maxRows,(int) $rowImages,(int) $thumbSizeX,(int) $thumbSizeY,$public,0,$visible,$sortorder,$sortdirection,$galleryimage,(int)$parentgallery,$showname,$showimageid,$showdescription,$showcreated,$showuser,$showhits,$showxysize,$showfilesize,$showfilename,$defaultscale,$geographic);
 			$result = $this->query($query,$bindvars);
-			$galleryId = $this->getOne("select max(`galleryId`) from `tiki_galleries` where `name`=? and `created`=?",array($name,(int) $now));
+			$galleryId = $this->getOne("select max(`galleryId`) from `tiki_galleries` where `name`=? and `created`=?",array($name,(int) $this->now));
 
-			global $feature_score;
-			if ($feature_score == 'y') {
+			if ($prefs['feature_score'] == 'y') {
 			    $this->score_event($user, 'igallery_new');
 			}
 		}
 
+		if ( $prefs['feature_search'] == 'y' && $prefs['feature_search_fulltext'] != 'y' && $prefs['search_refresh_index_mode'] == 'normal' ) {
+			require_once('lib/search/refresh-functions.php');
+			refresh_index('galleries', $galleryId);
+		}
+
 		return $galleryId;
 	}
 
 	function add_gallery_scale($galleryId, $scale) {
-		$query = "insert into `tiki_galleries_scales`(`galleryId`,`scale`)
+	        $old_scale = $this->getOne("select scale from tiki_galleries_scales where galleryId = ? AND scale = ?", array((int)$galleryId, (int)$scale));
+		if ($scale != $old_scale) {
+		    $query = "insert into `tiki_galleries_scales`(`galleryId`,`scale`)
             values(?,?)";
-
-		$result = $this->query($query,array((int)$galleryId,(int)$scale));
+		    $result = $this->query($query,array((int)$galleryId,(int)$scale));
+		}
 	}
 
 	function remove_gallery_scale($galleryId, $scale= 0) {
@@ -1784,7 +1842,7 @@ class ImageGalsLib extends TikiLib {
         }
 
 	function remove_gallery($id) {
-		global $gal_use_dir;
+		global $prefs;
 
 		$query = "select `imageId`,path from `tiki_images` where `galleryId`=?";
 		$result = $this->query($query,array((int) $id));
@@ -1818,7 +1876,7 @@ class ImageGalsLib extends TikiLib {
 				}
 
 				if ($path) {
-					@unlink ($gal_use_dir . $path . $ext);
+					@unlink ($prefs['gal_use_dir'] . $path . $ext);
 				}
 			}
 
@@ -1893,11 +1951,8 @@ class ImageGalsLib extends TikiLib {
 
 	//Capture Images from wiki, blogs, ....
 	function capture_images($data) {
-		global $tmpDir;
-		global $tikilib;
-		$cacheimages = $this->get_preference("cacheimages", 'y');
-
-		if ($cacheimages != 'y')
+		global $prefs, $tikilib;
+		if ($prefs['cacheimages'] != 'y')
 			return $data;
 
 		preg_match_all("/src=\"([^\"]+)\"/", $data, $reqs1);
@@ -1914,7 +1969,7 @@ class ImageGalsLib extends TikiLib {
 
 		foreach ($merge as $img) {
 			// This prevents caching images
-			if (!strstr($img, "show_image.php") && !strstr($img, "nocache") && @getimagesize($img)) {
+			if (!strstr($img, "img/wiki_up") && !strstr($img, "show_image.php") && !strstr($img, "nocache") && @getimagesize($img)) {
 				//print("Procesando: $img<br />");
 				@$fp = fopen($img, "r");
 
@@ -1967,7 +2022,7 @@ class ImageGalsLib extends TikiLib {
 							// CHECK IF THIS TEMP IS WRITEABLE OR CHANGE THE PATH TO A WRITEABLE DIRECTORY
 							//$tmpfname = 'temp.jpg';
 							//$tmpfname = tempnam("/tmp", "img");
-							$tmpfname = tempnam($tmpDir, "img");
+							$tmpfname = tempnam($prefs['tmpDir'], "img");
 							imagejpeg($t, $tmpfname);
 							// Now read the information
 							$fp = fopen($tmpfname, "rb");
@@ -1999,23 +2054,23 @@ class ImageGalsLib extends TikiLib {
 		return $page_data;
 	}
 	function get_one_image_from_disk($userfile, $galleryId=0, $name='', $description='', $gal_info='') {
-		global $tmpDir, $user;
+		global $prefs, $user;
 		$ret = array();
 		if (is_uploaded_file($_FILES[$userfile]['tmp_name'])) {
 			$file_name = $_FILES[$userfile]['name'];
 			$ret['filename'] = $file_name;
-			if (!empty($gal_match_regex) && !preg_match("/$gal_match_regex/", $file_name, $reqs)) {
+			if (!empty($prefs['gal_match_regex']) && !preg_match('/'.$prefs['gal_match_regex'].'/', $file_name, $reqs)) {
 				$ret['msg'] = tra('Invalid imagename (using filters for filenames)');
 				return $ret;
 			}
-			if (!empty($gal_nmatch_regex) && preg_match("/$gal_nmatch_regex/", $file_name, $reqs)) {
+			if (!empty($prefs['gal_nmatch_regex']) && preg_match('/'.$prefs['gal_nmatch_regex'].'/', $file_name, $reqs)) {
 				$ret['msg'] = tra('Invalid imagename (using filters for filenames)');
 				return $ret;
 			}
 			$type = $_FILES[$userfile]['type'];
 			$size = $_FILES[$userfile]['size'];
 			$file_tmp_name = $_FILES[$userfile]['tmp_name'];
-			$tmp_dest = $tmpDir . '/' . $file_name.'.tmp'; // add .tmp to not overwrite existing files (like index.php)
+			$tmp_dest = $prefs['tmpDir'] . '/' . $file_name.'.tmp'; // add .tmp to not overwrite existing files (like index.php)
 			if (!move_uploaded_file($file_tmp_name, $tmp_dest)) {
 				$ret['msg'] = tra('Errors detected');
 				@unlink($tmp_dest);
@@ -2055,14 +2110,19 @@ class ImageGalsLib extends TikiLib {
   // function to move images from one store to another (fs to db or db to fs)
   function move_image_store($imageId,$direction='to_fs')
   {
-    global $gal_use_db;
-    global $gal_use_dir;
+    global $prefs;
+
+		global $errstr;
     $this->clear_class_vars(); //cleanup
     
     if($direction!='to_fs' && $direction!='to_db') {
       return(false);
     }
     
+		if ($direction == 'to_fs' and !is_dir($prefs['gal_use_dir'])) {
+			$errstr = tra("unknown destination directory. Please set it up in <a href='tiki-admin.php?page=galleries'>tiki-admin.php?page=galleries</a>");
+			return(0);
+		}
     // get the storage location
     $query='select `path` from `tiki_images` where `imageId`=?';
     $path=$this->getOne($query,array($imageId),false);
@@ -2084,8 +2144,8 @@ class ImageGalsLib extends TikiLib {
       $this->store_image_data(true);
       if($direction=='to_db') {
         // remove image in fs 
-        if(!@unlink($gal_use_dir.$this->path)) {
-          $errstr="unlink failed";
+        if(!@unlink($prefs['gal_use_dir'].$this->path)) {
+          $errstr = tra("unlink failed");
         }
         $this->query($query,array('',$imageId));
       }
@@ -2172,8 +2232,7 @@ class ImageGalsLib extends TikiLib {
 			return min($t, $ybox/$ysize);
 		}
 	}
-  }
-
+	}
 }
 global $dbTiki;
 global $imagegallib;
