@@ -1,5 +1,5 @@
 <?php
-
+// $Id: /cvsroot/tikiwiki/tiki/lib/searchlib.php,v 1.48.2.6 2008-02-27 15:18:43 nyloth Exp $
 //test
 
 //this script may only be included - so its better to die if called directly.
@@ -10,12 +10,7 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
 
 class SearchLib extends TikiLib {
 	function SearchLib($db) {
-		# this is probably uneeded now
-		if (!$db) {
-			die ("Invalid db object passed to SearchLib constructor");
-		}
-
-		$this->db = $db;
+		$this->TikiLib($db);
 	}
 
 	function register_search($words) {
@@ -54,14 +49,15 @@ class SearchLib extends TikiLib {
 			'permName': the permission the user needs to see each result
 			'objectKey': the field corresponding to objectId according to users_objectpermissions table
 			'objectType': the object type according to users_objectpermissions
+			'parsed': true data needs to be parsed - optional
+			'is_html': if switch html or not - optional
  * \param fulltext: if true a full text search is done, if no result, a simple search is done
  * \param $words the list of words
  * //todo: extract the short words from the list and do a simple search on them, them merge with the full search results on the remaining words
  * \return the nb of results + array('name', 'data', 'hits', 'lastModif', 'href', 'pageName', 'relevance'
 **/
 	function _find($h, $words = '', $offset = 0, $maxRecords = -1, $fulltext = false) {
-		global $tiki_p_admin, $feature_categories, $feature_search_show_forbidden_obj,
-		    $feature_search_show_forbidden_cat, $userlib, $user, $categlib;
+		global $tiki_p_admin, $prefs, $userlib, $user, $categlib;
 		    
 		if (!is_object($categlib)) {
 			require_once('lib/categories/categlib.php');
@@ -77,9 +73,11 @@ class SearchLib extends TikiLib {
 		$bindJoin = array();
 		$bindHaving = array();
 
-		$sqlFields = sprintf(
-			'SELECT %s AS name, LEFT(%s, 240) AS data, %s AS hits, %s AS lastModif, %s AS pageName',
+		$sqlFields = sprintf('SELECT %s AS name, '.(isset($h['parsed'])? '%s':'LEFT(%s, 240) AS data').', %s AS hits, %s AS lastModif, %s AS pageName',
 					$h['name'], $h['data'], $h['hits'], $h['lastModif'], $h['pageName']);
+		if (isset($h['is_html'])) {
+			$sqlFields .= ', `is_html`';
+		}
 		
 		$id = $h['id'];
 		$temp_max = count($id);
@@ -130,7 +128,7 @@ class SearchLib extends TikiLib {
 		}
 		    
 		    
-		$chkObjPerm = $feature_search_show_forbidden_obj != 'y' && $tiki_p_admin != 'y' && (!empty($permName) || (!empty($permNameGlobal) && !empty($permNameObj))) && !empty($objType) && !empty($objKeyPerm) && !empty($objKeyGroup);
+		$chkObjPerm = $prefs['feature_search_show_forbidden_obj'] != 'y' && $tiki_p_admin != 'y' && (!empty($permName) || (!empty($permNameGlobal) && !empty($permNameObj))) && !empty($objType) && !empty($objKeyPerm) && !empty($objKeyGroup);
 
 		if ($chkObjPerm) {
 
@@ -154,11 +152,12 @@ class SearchLib extends TikiLib {
 			$bindHaving = array(0,1);
 	 	}
 
-		$chkCatPerm = $feature_search_show_forbidden_cat != 'y' && $tiki_p_admin != 'y' && !empty($objType) && !empty($objKeyCat) && !empty($objKeyGroup) && $feature_categories == 'y';
+		$chkCatPerm = $prefs['feature_search_show_forbidden_cat'] != 'y' && $tiki_p_admin != 'y' && !empty($objType) && !empty($objKeyCat) && !empty($objKeyGroup) && $prefs['feature_categories'] == 'y';
 
 		if ($chkCatPerm) {
 
-		    $sqlJoin .= " LEFT JOIN `tiki_categorized_objects` co ON co.`type`=? AND co.`objId`=$objKeyCat ";
+		    $sqlJoin .= " LEFT JOIN `tiki_objects` o ON o.`type`=? AND o.`itemId`=$objKeyCat ";
+		    $sqlJoin .= " LEFT JOIN `tiki_categorized_objects` co ON co.`catObjectId`=o.`objectId` ";
 		    $sqlJoin .= " LEFT JOIN `tiki_category_objects` cat ON co.`catObjectId`=cat.`catObjectId` ";
 
 		    $bindJoin[] = $objType;
@@ -170,13 +169,13 @@ class SearchLib extends TikiLib {
 		    }
                     if( $forbiddenCatStr == "" ) $forbiddenCatStr = '\'\'';
 
-		    $sqlFields .= ', co.`objId` IS NOT NULL as categorized, MAX(cat.`categId` IN ('.$forbiddenCatStr.')) as forbidden ';
+		    $sqlFields .= ', o.`itemId` IS NOT NULL as categorized, MAX(cat.`categId` IN ('.$forbiddenCatStr.')) as forbidden ';
 		    $bindFields = array_merge($bindFields, $forbiddenCatList);
 
 		    $sqlGroup = " GROUP BY $objKeyGroup ";
 
 		    if ($chkObjPerm) {
-			$sqlHaving = " HAVING (perms=? AND (NOT categorized OR NOT forbidden))";
+			$sqlHaving = " HAVING (perms=? AND (NOT categorized OR NOT forbidden OR forbidden IS NULL))";
 			if ($globalPerm == 'y') {
 				$sqlHaving .= " or ";
 			} else {
@@ -185,7 +184,7 @@ class SearchLib extends TikiLib {
 			$sqlHaving .= "allow=? ";
 			$bindHaving = array(0, 1);
 		    } else {
-			$sqlHaving = " HAVING NOT categorized OR NOT forbidden ";
+			$sqlHaving = " HAVING NOT categorized OR NOT forbidden OR forbidden IS NULL ";
 			$bindHaving = array();
 		    }
 		}
@@ -248,14 +247,14 @@ class SearchLib extends TikiLib {
 		$ret = array();
 
 		while ($res = $result->fetchRow(DB_FETCHMODE_ASSOC)) {
+			//if (($prefs['feature_search_show_forbidden_cat'] == 'y' || $prefs['feature_search_show_forbidden_obj'] == 'y') && !$this->user_has_perm_on_object($user,$res['id1'],$objType,$permName) continue;
 			$href = sprintf(urldecode($h['href']), urlencode($res['id1']), $res['id2']);
 
 			// taking first 240 chars of text can bring broken html tags, better remove all tags.
-			$res['data'] = preg_replace("/<[^>]+>/","",$res['data']);
-			$res['data'] = preg_replace("/<[^>]+$/","",$res['data']);
+			global $tikilib;
 			$ret[] = array(
 				'pageName' => $res["pageName"],
-				'data' => $res["data"],
+				'data' => $tikilib->get_snippet($res['data'], isset($res['is_html'])? $res['is_html']:'n'),
 				'hits' => $res["hits"],
 				'lastModif' => $res["lastModif"],
 				'href' => $href,
@@ -270,6 +269,7 @@ class SearchLib extends TikiLib {
 	}
 
 	function find_wikis($words = '', $offset = 0, $maxRecords = -1, $fulltext = false) {
+		global $tikilib, $prefs;
 		$rv = array();
 		$search_wikis_comments = array(
 			'from' => '`tiki_comments` c, `tiki_pages` p',
@@ -304,6 +304,10 @@ class SearchLib extends TikiLib {
 			'objectType' => 'wiki page',
 			'objectKey' => 'p.`pageName`',
 		);
+		if ($prefs['search_parsed_snippet'] == 'y') {
+			$search_wikis['is_html'] = 'is_html';
+			$search_wikis['parsed'] = true;
+		}
 
 		// that pagerank re-calculation was speed handicap (timex30)
 		//$this->pageRank();
@@ -322,7 +326,7 @@ class SearchLib extends TikiLib {
 			$data['cant'] += $rv['cant'];
 			return $data;
 		}
-			
+
 	}
 	function find_relevance_cmp($a, $b) {
 		return ($a['relevance'] > $b['relevance']) ? -1 : (($a['relevance'] < $b['relevance']) ? 1 : 0);
@@ -402,7 +406,7 @@ class SearchLib extends TikiLib {
  		return $this->_find($search_images, $words, $offset, $maxRecords, $fulltext);
 	}
 
-	function find_forums($words = '', $offset = 0, $maxRecords = -1, $fulltext = false) {
+	function find_forums($words = '', $offset = 0, $maxRecords = -1, $fulltext = false, $filter='') {
 		$search_forums = array(
 			'from' => '`tiki_comments` c, `tiki_forums` f',
 			'name' => 'c.`title`',
@@ -418,7 +422,11 @@ class SearchLib extends TikiLib {
 			'permName' => 'tiki_p_forum_read',
 			'objectType' => 'forum',
 			'objectKey' => 'f.`forumId`',
+			'objectKeyGroup' => 'c.`threadId`'
 		);
+		if (!empty($filter) && !empty($filter['forumId'])) {
+			$search_forums['filter'] .= ' AND f.forumId='.$filter['forumId'];
+		}
 
 		return $this->_find($search_forums, $words, $offset, $maxRecords, $fulltext);
 	}
@@ -428,13 +436,13 @@ class SearchLib extends TikiLib {
 			'from' => '`tiki_files` f',
 			'name' => 'f.`name`',
 			'data' => 'f.`description`',
-			'hits' => 'downloads',
+			'hits' => 'f.hits',
 			'lastModif' => 'f.`created`',
 			'href' => 'tiki-download_file.php?fileId=%d',
 			'id' => array('`fileId`'),
 			'pageName' => '`filename`',
 			'search' => array('f.`name`', 'f.`description`', 'f.`search_data`'),
-
+   			'filter' => '`archiveId` = 0',
 			'permName' => 'tiki_p_download_files',
 			'objectType' => 'file gallery',
 			'objectKey' => '`galleryId`',
@@ -488,12 +496,10 @@ class SearchLib extends TikiLib {
 	}
 
 	function find_posts($words = '', $offset = 0, $maxRecords = -1, $fulltext = false) {
-		global $user;
+	  global $user;
 
-		$site_timezone_shortname = $this->get_site_timezone_shortname();
-		$site_time_difference = $this->get_site_time_difference($user);
 		# TODO localize?
-		$pagename = "CONCAT(b.`title`, ' [', " . "DATE_FORMAT(FROM_UNIXTIME(p.created + $site_time_difference), " . "'%M %d %Y %h:%i'), ' $site_timezone_shortname', '] : ', p.`user`)";
+		$pagename = "CONCAT(b.`title`, ' - ', p.`user`)";
 
 		$search_posts = array(
 				      // why using left join here?
@@ -537,7 +543,7 @@ class SearchLib extends TikiLib {
 			'objectKey' => 'tt.`trackerId`',
 			'objectKeyPerm' => 'tt.`trackerId`',
 			'objectKeyCat' => 'tt.`trackerId`',
-			'objectKeyGroup' => 'tt.`trackerId`',
+			'objectKeyGroup' => 'ttif.`itemId`',
 		);
 		if ($tiki_p_view_trackers_closed != 'y')
 			$search_trackers['filter'] .= " AND tti.`status` != 'c'";
@@ -556,11 +562,9 @@ class SearchLib extends TikiLib {
 
 		$cant = 0;
 		
-		global $feature_wiki, $feature_directory, $feature_galleries, $feature_file_galleries,
-				$feature_articles, $feature_forums, $feature_blogs, $feature_faqs, $feature_trackers;
-		global $tiki_p_view_directory, $tiki_p_read_article, $tiki_p_view_faqs, $tiki_p_view_trackers;
+		global $prefs, $tiki_p_view_directory, $tiki_p_read_article, $tiki_p_view_faqs, $tiki_p_view_trackers;
 		
-		if ($feature_wiki == 'y') {
+		if ($prefs['feature_wiki'] == 'y') {
 		$rv = $this->find_wikis($words, $offset, $maxRecords, $fulltext);
 		foreach ($rv['data'] as $a) {
 			$a['type'] = tra('Wiki');
@@ -571,7 +575,7 @@ class SearchLib extends TikiLib {
 		$cant += $rv['cant'];
 		}
 		
-		if ($feature_galleries == 'y') {
+		if ($prefs['feature_galleries'] == 'y') {
 		$rv = $this->find_galleries($words, $offset, $maxRecords, $fulltext);
 
 		foreach ($rv['data'] as $a) {
@@ -583,7 +587,7 @@ class SearchLib extends TikiLib {
 		$cant += $rv['cant'];
 		}
 		
-		if ($feature_faqs == 'y' && $tiki_p_view_faqs == 'y') {
+		if ($prefs['feature_faqs'] == 'y' && $tiki_p_view_faqs == 'y') {
 		$rv = $this->find_faqs($words, $offset, $maxRecords, $fulltext);
 
 		foreach ($rv['data'] as $a) {
@@ -595,7 +599,7 @@ class SearchLib extends TikiLib {
 		$cant += $rv['cant'];
 		}
 		
-		if ($feature_galleries == 'y') {
+		if ($prefs['feature_galleries'] == 'y') {
 		$rv = $this->find_images($words, $offset, $maxRecords, $fulltext);
 
 		foreach ($rv['data'] as $a) {
@@ -607,7 +611,7 @@ class SearchLib extends TikiLib {
 		$cant += $rv['cant'];
 		}
 		
-		if ($feature_forums == 'y') {
+		if ($prefs['feature_forums'] == 'y') {
 		$rv = $this->find_forums($words, $offset, $maxRecords, $fulltext);
 
 		foreach ($rv['data'] as $a) {
@@ -619,7 +623,7 @@ class SearchLib extends TikiLib {
 		$cant += $rv['cant'];
 		}
 		
-		if ($feature_file_galleries == 'y') {
+		if ($prefs['feature_file_galleries'] == 'y') {
 		$rv = $this->find_files($words, $offset, $maxRecords, $fulltext);
 
 		foreach ($rv['data'] as $a) {
@@ -631,7 +635,7 @@ class SearchLib extends TikiLib {
 		$cant += $rv['cant'];
 		}
 		
-		if ($feature_blogs =='y') {
+		if ($prefs['feature_blogs'] =='y') {
 		$rv = $this->find_blogs($words, $offset, $maxRecords, $fulltext);
 
 		foreach ($rv['data'] as $a) {
@@ -643,7 +647,7 @@ class SearchLib extends TikiLib {
 		$cant += $rv['cant'];
 		}
 		
-		if ($feature_articles == 'y' && $tiki_p_read_article == 'y') {
+		if ($prefs['feature_articles'] == 'y' && $tiki_p_read_article == 'y') {
 		$rv = $this->find_articles($words, $offset, $maxRecords, $fulltext);
 
 		foreach ($rv['data'] as $a) {
@@ -655,7 +659,7 @@ class SearchLib extends TikiLib {
 		$cant += $rv['cant'];
 		}
 		
-		if ($feature_blogs == 'y') {
+		if ($prefs['feature_blogs'] == 'y') {
 		$rv = $this->find_posts($words, $offset, $maxRecords, $fulltext);
 
 		foreach ($rv['data'] as $a) {
@@ -667,7 +671,7 @@ class SearchLib extends TikiLib {
 		$cant += $rv['cant'];
 		}
 
-		if ($feature_directory == 'y' && $tiki_p_view_directory == 'y') {
+		if ($prefs['feature_directory'] == 'y' && $tiki_p_view_directory == 'y') {
 		$rv = $this->find_directory($words, $offset, $maxRecords, $fulltext);
 
 		foreach ($rv['data'] as $a) {
@@ -680,7 +684,7 @@ class SearchLib extends TikiLib {
 		$cant += $rv['cant'];
 		}
 
-		if ($feature_trackers == 'y' && $tiki_p_view_trackers == 'y') {
+		if ($prefs['feature_trackers'] == 'y' && $tiki_p_view_trackers == 'y') {
 		$rv = $this->find_trackers($words, $offset, $maxRecords, $fulltext);
 
 		foreach ($rv['data'] as $a) {
