@@ -17,9 +17,11 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
 function smarty_modifier_avatarize($user)
 {
   global $tikilib;
+  global $userlib;
   $avatar = $tikilib->get_user_avatar($user);
-  if ($tikilib->get_user_preference($user,'user_information','public')=='public') {
-  	$avatar = "<a title='$user' href='tiki-user_information.php?view_user=$user'>".$avatar.'</a>';
+  if ( $avatar != '' && $tikilib->get_user_preference($user, 'user_information', 'public') == 'public' ) {
+	$id = $userlib->get_user_id($user);
+  	$avatar = "<a title=\"$user\" href=\"tiki-user_information.php?userId=$id\">".$avatar.'</a>';
   } 
   return $avatar;	
 }
