@@ -7,12 +7,9 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
 }
 
 require_once $smarty->_get_plugin_filepath('modifier','tiki_date_format');
-function smarty_modifier_tiki_short_date($string)
-{
-	global $tikilib;
-	return smarty_modifier_tiki_date_format($string, $tikilib->get_short_date_format(), null, tra("%a %d of %b, %Y"));
+function smarty_modifier_tiki_short_date($string) {
+	global $prefs;
+	return smarty_modifier_tiki_date_format($string, $prefs['short_date_format']);
 }
 
-/* vim: set expandtab: */
-
 ?>
