@@ -1,4 +1,4 @@
-// $Header: /cvsroot/tikiwiki/tiki/lib/tiki-js.js,v 1.50.2.36 2007/08/14 12:43:47 luciash Exp $
+// $Header: /cvsroot/tikiwiki/tiki/lib/tiki-js.js,v 1.81.2.15 2008-03-04 15:47:50 sept_7 Exp $
 var feature_no_cookie = 'n';
 
 function browser() {
@@ -30,9 +30,36 @@ function getElementById(id) {
     }
 }
 
-function toggle_dynamic_var($name) {
-	name1 = 'dyn_'+$name+'_display';
-	name2 = 'dyn_'+$name+'_edit';
+/* toggle CSS (tableless) layout columns */
+function toggleCols(id,zeromargin,maincol) {
+	var showit = 'show_' + escape(id);
+	if (!zeromargin) var zeromargin = '';
+	if (!id) var id = '';
+	if (!maincol) var maincol = 'col1';
+	if (document.getElementById(id).style.display == "none") {
+		document.getElementById(id).style.display = "block";
+		if (zeromargin == 'left') {
+			document.getElementById(maincol).style.marginLeft = '';
+			setSessionVar(showit,'y');
+		} else {
+			document.getElementById(maincol).style.marginRight = '';
+			setSessionVar(showit,'y');
+		}
+	} else {
+		document.getElementById(id).style.display = "none";
+		if (zeromargin == 'left') {
+			document.getElementById(maincol).style.marginLeft = '0';
+			setSessionVar(showit,'n');
+		} else {
+			document.getElementById(maincol).style.marginRight = '0';
+			setSessionVar(showit,'n');
+		}
+	}
+}
+
+function toggle_dynamic_var(name) {
+	name1 = 'dyn_'+name+'_display';
+	name2 = 'dyn_'+name+'_edit';
 	if(document.getElementById(name1).style.display == "none") {
 		document.getElementById(name2).style.display = "none";
 		document.getElementById(name1).style.display = "inline";
@@ -163,19 +190,43 @@ function toggleToc() {
 function chgTrkFld(f,o) {
 	var opt = 0;
 	document.getElementById('z').style.display = "none";
+	document.getElementById('zDescription').style.display = "";
+	document.getElementById('zStaticText').style.display = "none";
+	document.getElementById('zStaticTextQuicktags').style.display = "none";
+
 	for (var i = 0; i < f.length; i++) {
 		var c = f.charAt(i);
 		if (document.getElementById(c)) { 
+			var ichoiceParent = document.getElementById('itemChoicesRow');
+			var ichoice = document.getElementById(c + 'itemChoices');
 			if (c == o) {
-				document.getElementById(c).style.display = "block";
+				document.getElementById(c).style.display = "";
 				document.getElementById('z').style.display = "block";
+				if (c == 'S') {
+					document.getElementById('zDescription').style.display = "none";
+					document.getElementById('zStaticText').style.display = "";
+					document.getElementById('zStaticTextQuicktags').style.display = "";
+				}
+				if (ichoice) {
+					ichoice.style.display = "";
+					ichoiceParent.style.display = "";
+				} else {
+					ichoiceParent.style.display = "none";
+				}
 			} else {
 				document.getElementById(c).style.display = "none";
+				if (ichoice) {
+					ichoice.style.display = "none";
+				}
 			}
 		}
 	}
 }
 
+function chgTrkLingual(item) {
+	document.getElementById("multilabelRow").style.display = ( item == 't' || item == 'a' ) ? '' : 'none';
+}
+
 function multitoggle(f,o) {
 	for (var i = 0; i < f.length; i++) {
 		if (document.getElementById('fid'+f[i])) { 
@@ -270,7 +321,7 @@ function setCaretToPos (textarea, pos) {
 function insertAt(elementId, replaceString) {
   //inserts given text at selection or cursor position
   textarea = getElementById(elementId);
-  var toBeReplaced = /text|page|area_name/;//substrings in replaceString to be replaced by the selection if a selection was done
+  var toBeReplaced = /text|page|area_name/g; //substrings in replaceString to be replaced by the selection if a selection was done
   if (textarea.setSelectionRange) {
     //Mozilla UserAgent Gecko-1.4
     var selectionStart = textarea.selectionStart;
@@ -338,14 +389,24 @@ function hide(foo,f, section) {
 	}
 }
 
-function flip(foo) {
+function flip(foo,style) {
+	showit = 'show_' + escape(foo);
+
+	if (style == null) style = 'block';
+	if (this.iewin && style == 'table-cell') {
+		style = 'block';
+	}
+
 	if (document.getElementById(foo).style.display == "none") {
-		show(foo);
+		document.getElementById(foo).style.display = style;
+		setSessionVar(showit,'y');
 	} else {
-		if (document.getElementById(foo).style.display == "block") {
-			hide(foo);
+		if (document.getElementById(foo).style.display == style) {
+			document.getElementById(foo).style.display = "none";
+			setSessionVar(showit, 'n');
 		} else {
-			show(foo);
+			document.getElementById(foo).style.display = style;
+			setSessionVar(showit, 'y');
 		}
 	}
 }
@@ -353,12 +414,9 @@ function flip(foo) {
 function toggle(foo) {
 	if (document.getElementById(foo).style.display == "none") {
 		show(foo, true, "menu");
-
-		setCookie(foo, "o");
 	} else {
 		if (document.getElementById(foo).style.display == "block") {
 			hide(foo, true, "menu");
-			setCookie(foo, "c");
 		} else {
 			show(foo, true, "menu");
 		}
@@ -383,13 +441,13 @@ function tikitabs(focus,max) {
 				//show(tabname);
 				show(content);
 				setCookie('tab',focus);
-				document.getElementById(tabname).style.borderColor="black";
-				document.getElementById(tabname).style.borderWidth="1px";
+				document.getElementById(tabname).className = 'tabmark';
+				document.getElementById(tabname).className += ' tabactive';
 			} else {
 				//hide(tabname);
 				hide(content);
-				document.getElementById(tabname).style.borderColor="transparent";
-				document.getElementById(tabname).style.borderWidth="0";
+				document.getElementById(tabname).className = 'tabmark';
+				document.getElementById(tabname).className += ' tabinactive';
 			}
 		}
 	}
@@ -397,19 +455,24 @@ function tikitabs(focus,max) {
 
 function setfoldericonstate(foo) {
 	if (getCookie(foo, "menu", "o") == "o") {
-		src = "ofo.gif";
+		src = "ofolder.png";
 	} else {
-		src = "fo.gif";
+		src = "folder.png";
 	}
-	document.getElementsByName(foo + 'icn')[0].src = document.getElementsByName(foo + 'icn')[0].src.replace(/[^\\\/]*$/, src);
+	document.getElementsByName('icn' + foo)[0].src = document.getElementsByName('icn' + foo)[0].src.replace(/[^\\\/]*$/, src);
 }
 /* foo: name of the menu
  * def: menu type (e:extended, c:collapsed, f:fixed)
  * the menu is collapsed function of its cookie: if no cookie is set, the def is used
  */
-function setfolderstate(foo, def) {
+function setfolderstate(foo, def, img) {
 	var status = getCookie(foo, "menu", "o");
-    var img = "fo.gif";
+    if (!img) {
+		if (document.getElementsByName('icn' + foo)[0].src.search(/[\\\/]/))
+			img = document.getElementsByName('icn' + foo)[0].src.replace(/.*[\\\/]([^\\\/]*)$/, "$1");
+		else
+			img = 'folder.png';
+	}
     var src = img; // default
 	if (status == "o") {
 		show(foo);
@@ -421,7 +484,20 @@ function setfolderstate(foo, def) {
 	else {
 		hide(foo);
 	}
-	document.getElementsByName(foo + 'icn')[0].src = document.getElementsByName(foo + 'icn')[0].src.replace(/[^\\\/]*$/, src);
+	document.getElementsByName('icn' + foo)[0].src = document.getElementsByName('icn' + foo)[0].src.replace(/[^\\\/]*$/, src);
+}
+
+function setheadingstate(foo) {
+	var status = getCookie(foo, "showhide_headings");
+	if (status == "o") {
+		show(foo);
+		collapseSign("flipper" + foo);
+	} else /*if (status == "c")*/ {
+		if (!document.getElementById(foo).style.display == "none") {
+			hide(foo);
+			expandSign("flipper" + foo);
+		}
+	}
 }
 
 function setsectionstate(foo, def, img) {
@@ -436,18 +512,24 @@ function setsectionstate(foo, def, img) {
 		hide(foo);
 		if (img) src = img;
 	}
-	if (img) document.getElementsByName(foo + 'icn')[0].src = document.getElementsByName(foo + 'icn')[0].src.replace(/[^\\\/]*$/, src);
+	if (img) document.getElementsByName('icn' + foo)[0].src = document.getElementsByName('icn' + foo)[0].src.replace(/[^\\\/]*$/, src);
 }
 
 function icntoggle(foo, img) {
-	if (!img) img = "fo.gif";
+    if (!img) {
+		if (document.getElementsByName('icn' + foo)[0].src.search(/[\\\/]/))
+			img = document.getElementsByName('icn' + foo)[0].src.replace(/.*[\\\/]([^\\\/]*)$/, "$1");
+		else
+			img = 'folder.png';
+	}
 	if (document.getElementById(foo).style.display == "none") {
 		show(foo, true, "menu");
-		document.getElementsByName(foo + 'icn')[0].src = document.getElementsByName(foo + 'icn')[0].src.replace(/[^\\\/]*$/, 'o' + img);
+		document.getElementsByName('icn' + foo)[0].src = document.getElementsByName('icn' + foo)[0].src.replace(/[^\\\/]*$/, 'o' + img);
 		
 	} else {
 		hide(foo, true, "menu");
-		document.getElementsByName(foo + 'icn')[0].src = document.getElementsByName(foo + 'icn')[0].src.replace(/[^\\\/]*$/, img);
+		img = img.replace(/(^|\/|\\)o(.*)$/, '$1$2');
+		document.getElementsByName('icn' + foo)[0].src = document.getElementsByName('icn' + foo)[0].src.replace(/[^\\\/]*$/, img);
 	}
 }
 
@@ -480,8 +562,11 @@ function setFolderIcons() {
 //		(HTTP Response Code [200,403, 404, ...])
 // method - GET or POST
 // url - The URL to open
-function getHttpRequest( method, url )
+function getHttpRequest( method, url, async )
 {
+	if( async == null )
+		async = false;
+
 	var request;
 
 	if( window.XMLHttpRequest )
@@ -503,7 +588,7 @@ function getHttpRequest( method, url )
 	if( !request )
 		return false;
 
-	request.open( method, url, false );
+	request.open( method, url, async );
 
 	return request;
 }
@@ -516,6 +601,12 @@ function getHttpRequest( method, url )
 // [secure] - Boolean value indicating if the cookie transmission requires a secure transmission
 // * an argument defaults when it is assigned null as a placeholder
 // * a null placeholder is not required for trailing omitted arguments
+function setSessionVar(name,value) {
+	var request = getHttpRequest( "GET", "tiki-cookie-jar.php?" + name + "=" + escape(value));
+	request.send('');
+	tiki_cookie_jar[name] = value;
+}
+
 function setCookie(name, value, section, expires, path, domain, secure) {
     if (!expires) {
         expires = new Date();
@@ -653,15 +744,11 @@ function fixDate(date) {
 //
 function flipWithSign(foo) {
 	if (document.getElementById(foo).style.display == "none") {
-		show(foo);
-
+		show(foo, true, "showhide_headings");
 		collapseSign("flipper" + foo);
-		setCookie(foo, "o");
 	} else {
-		hide(foo);
-
+		hide(foo, true, "showhide_headings");
 		expandSign("flipper" + foo);
-		setCookie(foo, "c");
 	}
 }
 
@@ -701,13 +788,16 @@ function switchCheckboxes(tform, elements_name, state) {
 }  
 
 //
-// Set client offset (in minutes) to a cookie to avoid server-side DST issues
+// Set client timezone
 // Added 7/25/03 by Jeremy Jongsma (jjongsma@tickchat.com)
+// Updated 11/04/07 by Nyloth to get timezone name instead of timezone offset
 //
+
 var expires = new Date();
-var offset = -(expires.getTimezoneOffset() * 60);
+var local_date = expires.toLocaleString();
+var local_tz = local_date.substring(local_date.lastIndexOf(' ') + 1);
 expires.setFullYear(expires.getFullYear() + 1);
-setCookie("tz_offset", offset, null, expires, "/");
+setCookie("local_tz", local_tz, null, expires, "/");
 
 // function added for use in navigation dropdown
 // example :
@@ -795,7 +885,7 @@ function textareasize(elementId, height, width, formId) {
 /** \brief: insert img tag in textarea
  *	
  */	
-function insertImg(elementId, fileId, oldfileId) {
+function insertImgFile(elementId, fileId, oldfileId,type,page,attach_comment) {
     textarea = getElementById(elementId);
     fileup   = getElementById(fileId);    
     oldfile  = getElementById(oldfileId);    
@@ -830,10 +920,28 @@ function insertImg(elementId, fileId, oldfileId) {
     }
     // @todo - here's a hack: we know its ending up in img/wiki_up. 
     //      replace with dyn. variable once in a while to respect the tikidomain 
-    str = "{img src=\"img/wiki_up/" + filename + "\" }";
+    if (type == "file") {
+        str = "{file name=\""+filename + "\" page=\"" + getElementById(page).value + "\"";
+        if (desc = getElementById(attach_comment).value)
+             str = str + " desc=\""+ desc + "\"";
+        str = str + "}";
+    }
+    else
+        str = "{img src=\"img/wiki_up/" + filename + "\" }\n";
     insertAt(elementId, str);
 }
 
+/* add new upload image form in page edition */
+var img_form_count = 2;
+function addImgForm() {
+	var new_text = document.createElement('span');
+	new_text.setAttribute('id','picfile' + img_form_count);
+	new_text.innerHTML = '<input name=\'picfile' + img_form_count + '\' type=\'file\' onchange=\'javascript:insertImgFile("editwiki","picfile' + img_form_count + '","hasAlreadyInserted","img")\'/><br />';
+	document.getElementById('new_img_form').appendChild(new_text);
+	needToConfirm = true;
+	img_form_count ++;
+}
+
 /*
  * opens wiki 3d browser
  */
@@ -841,6 +949,11 @@ function wiki3d_open (page, width, height) {
     window.open('tiki-wiki3d.php?page='+page,'wiki3d','width='+width+',height='+height+',scrolling=no');
 }
 
+/* some little email protection */
+function protectEmail(nom, domain, sep) {
+		document.write('<a class="wiki" href="mailto:'+nom+'@'+domain+'">'+nom+sep+domain+'</a>');
+}
+
 // --- begin of sorttable, written by Stuart Langridge, November 2003, MIT license ---
 addEvent(window, "load", sortables_init);
 
@@ -922,11 +1035,11 @@ function ts_resortTable(lnk) {
     newRows.sort(sortfn);
 
     if (span.getAttribute("sortdir") == 'down') {
-        ARROW = '&nbsp;&nbsp;<img src="img/icons2/up.gif" border="0">';
+        ARROW = '&nbsp;&nbsp;<img src="pics/icons/resultset_up.png" border="0" width="16" height="16" />';
         newRows.reverse();
         span.setAttribute('sortdir','up');
     } else {
-        ARROW = '&nbsp;&nbsp;<img src="img/icons2/down.gif" border="0">';
+        ARROW = '&nbsp;&nbsp;<img src="pics/icons/resultset_down.png" border="0" width="16" height="16" />';
         span.setAttribute('sortdir','down');
     }
     
@@ -1009,6 +1122,16 @@ function ts_sort_default(a,b) {
     return 1;
 }
 
+// function to allow multiselection in checkboxes
+// must be called like this : 
+//
+// <input type="checkbox" onclick="checkbox_list_check_all(form_name,[checkbox_name_1,checkbox_name2 ...],true|false);">
+function checkbox_list_check_all(form,list,checking) {
+	for (var checkbox in list) {
+		document.forms[form].elements[list[checkbox]].checked=checking;	
+	}
+}
+
 
 function addEvent(elm, evType, fn, useCapture)
 // addEvent and removeEvent
@@ -1025,8 +1148,94 @@ function addEvent(elm, evType, fn, useCapture)
     alert("Handler could not be removed");
   }
 } 
-// --- end of sorttable ---
 
+function adjustThumbnails() {
+  var i,j,h = 0;
+  var t = document.getElementById("thumbnails").childNodes;
+  for ( i = 0; i < t.length; i++ ) {
+    if ( t[i].className == "thumbnailcontener" ) {
+      var t2 = t[i].childNodes;
+      for ( j = 0; j < t2.length; j++ ) {
+        if ( t2[j].className == "thumbnail" ) {
+          t2[j].style.height = "100%";
+          t2[j].style.overflow = "visible";
+        }
+      }
+      if ( t[i].offsetHeight >= h ) {
+        h = t[i].offsetHeight;
+        t[i].style.height = h+"px";
+      } else if ( t[i].offsetHeight < h ) {
+        t[i].style.height = h+"px";
+      }
+    }
+  }
+  for ( i = 0; i < t.length; i++ ) {
+    if ( t[i].className == "thumbnailcontener" ) {
+      if ( t[i].offsetHeight <= h ) {
+        t[i].style.height = h+"px";
+      } else {
+        break;
+      }
+    }
+  }
+}
+
+// --- end of sorttable ---
+/* do not need if all pngs are png8
+function correctPNG() // correctly handle PNG transparency in Win IE 5.5 & 6.
+{
+   var arVersion = navigator.appVersion.split("MSIE")
+   var version = parseFloat(arVersion[1])
+   if ((version >= 5.5) && (document.body.filters)) 
+   {
+      for(var i=0; i<document.images.length; i++)
+      {
+         var img = document.images[i]
+         var imgName = img.src.toUpperCase()
+         if (imgName.substring(imgName.length-3, imgName.length) == "PNG")
+         {
+            var imgID = (img.id) ? "id='" + img.id + "' " : ""
+            var imgClass = (img.className) ? "class='" + img.className + "' " : ""
+            var imgTitle = (img.title) ? "title='" + img.title + "' " : "title='" + img.alt + "' "
+            var imgStyle = "display:inline-block;" + img.style.cssText 
+            if (img.align == "left") imgStyle = "float:left;" + imgStyle
+            if (img.align == "right") imgStyle = "float:right;" + imgStyle
+            if (img.parentElement.href) imgStyle = "cursor:hand;" + imgStyle
+            var strNewHTML = "<span " + imgID + imgClass + imgTitle
+            + " style=\"" + "width:" + img.width + "px; height:" + img.height + "px;" + imgStyle + ";"
+            + "filter:progid:DXImageTransform.Microsoft.AlphaImageLoader"
+            + "(src=\'" + img.src + "\', sizingMethod='scale');\"></span>" 
+            img.outerHTML = strNewHTML
+            i = i-1
+         }
+      }
+   }    
+}
+*/
+browser();
+/* do not need if all the pngs are png8
+if (this.iewin) {
+	window.attachEvent("onload", correctPNG);
+
+}
+*/
 // This was added to allow wiki3d to change url on tiki's window
 window.name = 'tiki';
 
+/* Function to add image from filegals in non wysiwyg editor */
+/* must be here when ajax is activated                       */
+function SetUrl(url) {
+  str = "{img src=" + url + " }\n";
+  insertAt('editwiki', str);
+}
+/* Count the number of words (spearated with space) */
+function wordCount(maxSize, source, cpt, message) {
+	var formcontent = source.value;
+	str = formcontent.replace(/^\s+|\s+$/g, '') ;
+	formcontent = str.split(/[^\S]+/);
+	document.getElementById(cpt).value = formcontent.length;
+	if (maxSize > 0 && formcontent.length > maxSize) {
+        alert(message);
+	}
+}
+
