@@ -1,12 +1,12 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/lib/wiki-plugins/wikiplugin_agentinfo.php,v 1.2.2.3 2005/01/03 19:28:28 redflo Exp $
+// $Id: /cvsroot/tikiwiki/tiki/lib/wiki-plugins/wikiplugin_agentinfo.php,v 1.5.2.1 2007-12-07 12:55:20 pkdille Exp $
 
 // Wiki plugin to display a browser client information
 // damian aka damosoft May 2004
 
 function wikiplugin_agentinfo_help() {
-        return tra("Displays browser client info").":<br :>~np~{AGENTINFO(info=>IP or SVRSW or BROWSER)/}~/np~";
+        return tra("Displays browser client info").":<br />~np~{AGENTINFO(info=>IP or SVRSW or BROWSER)/}~/np~";
 }
 
 function wikiplugin_agentinfo($data, $params) {
