@@ -1,5 +1,5 @@
 <?php
-/** $Header: /cvsroot/tikiwiki/tiki/modules/mod-breadcrumb.php,v 1.5.2.1 2004/08/26 17:39:15 mose Exp $
+/** $Id: mod-breadcrumb.php 12270 2008-03-30 20:06:05Z luciash $
  * \param maxlen = max number of displayed characters for the page name
  */
 
@@ -12,8 +12,7 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
 if (!isset($_SESSION["breadCrumb"])) {
 	$_SESSION["breadCrumb"] = array();
 }
-
-$bbreadCrumb = array_reverse($_SESSION["breadCrumb"]);
+$bbreadCrumb = array_slice(array_reverse($_SESSION["breadCrumb"]), 0, $module_rows);
 $smarty->assign('breadCrumb', $bbreadCrumb);
 $smarty->assign('maxlen', isset($module_params["maxlen"]) ? $module_params["maxlen"] : 0);
 ?>
