@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/show_image.php,v 1.21.2.14 2007/03/02 12:23:30 luciash Exp $
+// $Id: /cvsroot/tikiwiki/tiki/show_image.php,v 1.34.2.1 2007-12-07 05:56:37 mose Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -17,7 +17,7 @@ include_once ("lib/imagegals/imagegallib.php");
 // application to display an image from the database with 
 // option to resize the image dynamically creating a thumbnail on the fly.
 // you have to check if the user has permission to see this gallery
-if ($feature_galleries != 'y') {
+if ($prefs['feature_galleries'] != 'y') {
    header("HTTP/1.0 404 Not Found");
 	die;
 }
@@ -27,8 +27,6 @@ if (isset($_REQUEST["name"])) {
 	$id=$imagegallib->get_imageid_byname($_REQUEST["name"]);
 } elseif (isset($_REQUEST["id"])) {
 	$id=$_REQUEST["id"];
-} elseif (isset($_REQUEST["galleryId"])) {
-	$id=$imagegallib->get_gallery_image($_REQUEST["galleryId"], 'random');
 }
 
 if (!$id) {
@@ -53,7 +51,7 @@ if ($userlib->object_has_one_permission($galleryId, 'image gallery')) {
 			}
 		}
 	}
-} elseif ($tiki_p_admin != 'y' && $feature_categories == 'y') {
+} elseif ($tiki_p_admin != 'y' && $prefs['feature_categories'] == 'y') {
 	global $categlib;
 	if (!is_object($categlib)) {
 		include_once('lib/categories/categlib.php');
@@ -67,7 +65,7 @@ if ($userlib->object_has_one_permission($galleryId, 'image gallery')) {
    	} else {
    		$is_categorized = FALSE;
    	}
-	if ($is_categorized && isset($tiki_p_view_categories) && $tiki_p_view_categories != 'y') {
+	if ($is_categorized && isset($tiki_p_view_categorized) && $tiki_p_view_categorized != 'y') {
         header("HTTP/1.0 404 Not Found");
         die;
 	}
@@ -144,7 +142,7 @@ header ("Etag: ".$imagegallib->etag);
 
 header ("Content-Disposition: inline; filename=\"" . $imagegallib->filename.'"');
 //if($data["path"]) {
-//  readfile($gal_use_dir.$data["path"].$ter);
+//  readfile($prefs['gal_use_dir'].$data["path"].$ter);
 //} else {
 echo $imagegallib->image;
 //}
