@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-assignpermission.php,v 1.18.2.12 2007/03/02 12:23:11 luciash Exp $
+// $Id: /cvsroot/tikiwiki/tiki/tiki-assignpermission.php,v 1.35.2.1 2007-12-29 16:30:00 jyhem Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -11,13 +11,11 @@
 // Initialization
 require_once ('tiki-setup.php');
 
-if ($user != 'admin') {
-	if ($tiki_p_admin != 'y') {
-		$smarty->assign('msg', tra("You do not have permission to use this feature"));
-
-		$smarty->display("error.tpl");
-		die;
-	}
+if ($tiki_p_admin != 'y') {
+	$smarty->assign('errortype', 401);
+	$smarty->assign('msg', tra("You do not have permission to use this feature"));
+	$smarty->display("error.tpl");
+	die;
 }
 
 if (!isset($_REQUEST["group"])) {
@@ -30,7 +28,7 @@ if (!isset($_REQUEST["group"])) {
 $group = $_REQUEST["group"];
 
 if (!$userlib->group_exists($group)) {
-	$smarty->assign('msg', tra("Group doesnt exist"));
+	$smarty->assign('msg', tra("Group doesn't exist"));
 
 	$smarty->display("error.tpl");
 	die;
@@ -39,13 +37,15 @@ if (!$userlib->group_exists($group)) {
 $smarty->assign_by_ref('group', $group);
 
 if (isset($_REQUEST['allper'])) {
-	check_ticket('admin-perms');
-	if ($_REQUEST['oper'] == 'assign') {
-		$userlib->assign_level_permissions($group, $_REQUEST['level']);
-		$logslib->add_log('perms',"assigned all perms level ".$_REQUEST['level']." to group $group");
-	} else {
-		$userlib->remove_level_permissions($group, $_REQUEST['level']);
-		$logslib->add_log('perms',"unassigned all perms level ".$_REQUEST['level']." from group $group");
+	check_ticket('admin-perms');	
+	foreach ($_REQUEST['level'] as $t_level) { 
+		if ($_REQUEST['oper'] == 'assign') {
+			$userlib->assign_level_permissions($group, $t_level);
+			$logslib->add_log('perms',"assigned all perms level ".$t_level." to group $group");
+		} else {
+			$userlib->remove_level_permissions($group, $t_level);
+			$logslib->add_log('perms',"unassigned all perms level ".$t_level." from group $group");
+		}
 	}
 }
 
@@ -58,12 +58,12 @@ if (isset($_REQUEST["action"])) {
 
 	if ($_REQUEST["action"] == 'remove') {
 		$area = 'delpermassign';
-		if ($feature_ticketlib2 != 'y' or (isset($_POST['daconfirm']) and isset($_SESSION["ticket_$area"]))) {
+		if ($prefs['feature_ticketlib2'] != 'y' or (isset($_POST['daconfirm']) and isset($_SESSION["ticket_$area"]))) {
 			key_check($area);
 			$userlib->remove_permission_from_group($_REQUEST["permission"], $group);
 			$logslib->add_log('perms',"unassigned perm ".$_REQUEST['permission']." from group $group");
 		} else {
-			key_get($area);
+			key_get($area, sprintf(tra('Unassign perm %s from group %s'), $_REQUEST['permission'], $group));
 		}
 	}
 }
@@ -82,19 +82,6 @@ if (!isset($_REQUEST["sort_mode"])) {
 
 $smarty->assign_by_ref('sort_mode', $sort_mode);
 
-$maxRecords = 9999;
-
-// If offset is set use it if not then use offset =0
-// use the maxRecords php variable to set the limit
-// if sortMode is not set then use lastModif_desc
-if (!isset($_REQUEST["offset"])) {
-	$offset = 0;
-} else {
-	$offset = $_REQUEST["offset"];
-}
-
-$smarty->assign_by_ref('offset', $offset);
-
 if (isset($_REQUEST["find"])) {
 	$find = $_REQUEST["find"];
 } else {
@@ -137,34 +124,29 @@ $levels = $userlib->get_permission_levels();
 sort($levels);
 $smarty->assign('levels', $levels);
 
-$perms = $userlib->get_permissions($offset, $maxRecords, $sort_mode, $find, $_REQUEST["type"], $group);
-$cant_pages = ceil($perms["cant"] / $maxRecords);
-$smarty->assign_by_ref('cant_pages', $cant_pages);
-$smarty->assign('actual_page', 1 + ($offset / $maxRecords));
+$perms = $userlib->get_permissions(0, -1, $sort_mode, $find, $_REQUEST["type"], $group);
 
-if ($perms["cant"] > ($offset + $maxRecords)) {
-	$smarty->assign('next_offset', $offset + $maxRecords);
-} else {
-	$smarty->assign('next_offset', -1);
-}
-
-// If offset is > 0 then prev_offset
-if ($offset > 0) {
-	$smarty->assign('prev_offset', $offset - $maxRecords);
-} else {
-	$smarty->assign('prev_offset', -1);
+foreach ($perms['data'] as $perm) {
+ 	if ($perm['admin'] == 'y' && $perm['hasPerm'] == 'y') {
+		foreach ($perms['data'] as $key=>$p) {
+			if ($p['type'] == $perm['type'] && $perm['permName'] != $p['permName']) {
+				$perms['data'][$key]['from_admin'] = 'y';
+				$perms['data'][$key]['hasPerm'] = 'y';
+			}
+		}
+	}
 }
 
 if ($group != 'Anonymous') {
 	// Get the list of permissions for anony
-	$ifa = $userlib->get_permissions($offset, $maxRecords, $sort_mode, $find,$_REQUEST["type"],'Anonymous');
+	$ifa = $userlib->get_permissions(0, -1, $sort_mode, $find,$_REQUEST["type"],'Anonymous');
 	$smarty->assign_by_ref('inherited_from_anon', $ifa['data']);
 	if ($group != 'Registered') {
-		$ifr = $userlib->get_permissions($offset, $maxRecords, $sort_mode, $find,$_REQUEST["type"],'Registered');
+		$ifr = $userlib->get_permissions(0, -1, $sort_mode, $find,$_REQUEST["type"],'Registered');
 		$smarty->assign_by_ref('inherited_from_reg', $ifr['data']);
 		$incgroups = $userlib->get_included_groups($group);
 		foreach($incgroups as $ig) {
-			$ixr = $userlib->get_permissions($offset, $maxRecords, $sort_mode, $find,$_REQUEST["type"],$ig);
+			$ixr = $userlib->get_permissions(0, -1, $sort_mode, $find,$_REQUEST["type"],$ig);
 			$back[$ig] = $ixr['data'];
 		}
 		$smarty->assign_by_ref('inherited_groups_perms',$back);
