@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-setup_base.php,v 1.78.2.74 2008/02/21 20:08:06 lphuberdeau Exp $
+// $Id: /cvsroot/tikiwiki/tiki/tiki-setup_base.php,v 1.142.2.8 2008-03-22 05:12:47 mose Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -10,6 +10,7 @@
 if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
   header("location: index.php");
   exit;
+	die();
 }
 
 // ---------------------------------------------------------------------
@@ -39,23 +40,83 @@ ini_set('allow_call_time_pass_reference','On');
 // ---------------------------------------------------------------------
 // inclusions of mandatory stuff and setup
 require_once("lib/tikiticketlib.php");
-require_once("db/tiki-db.php"); 
+require_once("db/tiki-db.php");
 require_once("setup_smarty.php"); 
 require_once("lib/tikilib.php");
 require_once("lib/cache/cachelib.php");
 require_once("lib/logs/logslib.php");
 include_once('lib/init/tra.php');
-
 $tikilib = new TikiLib($dbTiki);
+
+// Get tiki-setup_base needed preferences in one query
+$prefs = array();
+$needed_prefs = array(
+	'session_lifetime' => '0',
+	'session_db' => 'n',
+	'sessions_silent' => 'disabled',
+	'language' => 'en',
+	'cookie_name' => 'tikiwiki',
+	'rememberme' => 'disabled',
+	'feature_intertiki' => 'n',
+	'tiki_key' => '',
+	'feature_intertiki_mymaster' => '',
+	'feature_intertiki_sharedcookie' => 'n',
+	'interlist' => array(),
+	'auth_method' => 'tiki',
+	'smarty_security' => 'n'
+);
+$tikilib->get_preferences($needed_prefs, true, true);
+extract($prefs);
+
+// Handle Smarty Security
+if ( $prefs['smarty_security'] == 'y' ) {
+	$smarty->security = true;
+}
+
+// set session lifetime
+if ($prefs['session_lifetime'] > 0) {
+	ini_set('session.gc_maxlifetime',$prefs['session_lifetime']*60);
+}
+
+// is session data  stored in DB or in filesystem?
+if ($prefs['session_db'] == 'y') {
+	include('db/local.php');
+	$ADODB_SESSION_DRIVER=$db_tiki;
+	$ADODB_SESSION_CONNECT=$host_tiki;
+	$ADODB_SESSION_USER=$user_tiki;
+	$ADODB_SESSION_PWD=$pass_tiki;
+	$ADODB_SESSION_DB=$dbs_tiki;
+	unset($db_tiki);
+	unset($host_tiki);
+	unset($user_tiki);
+	unset($pass_tiki);
+	unset($dbs_tiki);
+	ini_set('session.save_handler','user');
+	include_once('lib/adodb/session/adodb-session.php');
+}
+
+// Only accept PHP's session ID in URL when the request comes from the tiki server itself
+// This is used by features that need to query the server to retrieve tiki's generated html and images (e.g. pdf export)
+if ( isset($_GET['PHPSESSID']) && $_SERVER['REMOTE_ADDR'] == '127.0.0.1' ) {
+	$_COOKIE['PHPSESSID'] = $_GET['PHPSESSID'];
+	session_id($_GET['PHPSESSID']);
+}
+if ($sessions_silent == 'disabled' or !empty($_COOKIE)) {
+	// enabing silent sessions mean a session is only started when a cookie is presented
+	session_start();
+}
+
 require_once("lib/userslib.php");
 $userlib = new UsersLib($dbTiki);
-
+require_once("lib/tikiaccesslib.php");
+$access = new TikiAccessLib();
 require_once("lib/breadcrumblib.php");
 //require_once("lib/tikihelplib.php");
 
 // ------------------------------------------------------
 // DEAL WITH XSS-TYPE ATTACKS AND OTHER REQUEST ISSUES
 
+require_once('lib/setup/sanitization.php');
 function make_clean(&$var,$gpc=false) {
 	if ( is_array($var) ) {
 		foreach ( $var as $key=>$val ) {
@@ -63,13 +124,9 @@ function make_clean(&$var,$gpc=false) {
 		}
 	} else {
 		if ($gpc) $var = stripslashes($var);
-		$var = preg_replace("~</?\s*(embed|object|applet)[^>]*>~si","",$var);
-		if (preg_match("~</?\s*script[^>]*>?~si",$var)) {
-			$var = preg_replace("~</?\s*script[^>]*>?~si","",$var);
-			make_clean($var);
+		if ( ! isset($_SERVER['SCRIPT_FILENAME']) || basename($_SERVER['SCRIPT_FILENAME']) != 'tiki-admin.php' ) {
+			$var = RemoveXSS($var);
 		}
-		$var = preg_replace('~(inhibited_|on)(mouseover|mouseout|load|click|dblclick|focus|mousedown|mouseup|mousemove|mouseenter|mouseleave|blur|change|keydown|keypress|keyup|abort|dragdrop|error|load|move|reset|resize|select|submit|unload)(\s*)?=~si','inhibited_$2$3=',$var);
-		$var = preg_replace('~(=\s*["\']?\s*)javascript\s*:~si','$1inhibited_js:',$var);
 	}
 }
 
@@ -110,23 +167,34 @@ if ( false ) { // if pre-PHP 4.1 compatibility is not required
 $patterns['login']   = "/^[-_a-zA-Z0-9@\.]*$/"; // special check for logins, not to be used in varcheck because compat with already created accounts
 $patterns['int']   = "/^[0-9]*$/"; // *Id
 $patterns['intSign']   = "/^[-+]?[0-9]*$/"; // *offset,
-$patterns['char']  = "/^[-,_a-zA-Z0-9]*$/"; // sort_mode 
+$patterns['char']  = "/^(pref:)?[-,_a-zA-Z0-9]*$/"; // sort_mode 
 $patterns['string']  = "/^<\/?(b|strong|small|br *\/?|ul|li|i)>|[^<>\";#]*$/"; // find, and such extended chars
 $patterns['stringlist']  = "/^[^<>\"#]*$/"; // to, cc, bcc (for string lists like: user1;user2;user3)
 $patterns['vars']  = "/^[-_a-zA-Z0-9]*$/"; // for variable keys
+$patterns['dotvars']  = "/^[-_a-zA-Z0-9\.]*$/"; // same pattern as a variable key, but that may contain a dot
 $patterns['hash'] = "/^[a-z0-9]*$/"; // for hash reqId in live support
+// needed for the htmlpage inclusion in tiki-editpage
 $patterns['url'] = "/^(https?:\/\/)?[^<>\"']*$/"; // needed for the htmlpage inclusion in tiki-editpage
 
 // parameter type definitions. prepend a + if variable may not be empty, e.g. '+int'
 $vartype['id'] = '+int';
 $vartype['forumId'] = '+int';
 $vartype['offset'] = 'intSign';
+$vartype['prev_offset'] = 'intSign';
+$vartype['next_offset'] = 'intSign';
 $vartype['thresold'] = 'int';
 $vartype['sort_mode'] = '+char'; // TODO: only allow valid field names and order here!
+$vartype['file_sort_mode'] = 'char';
+$vartype['file_offset'] = 'int';
+$vartype['file_find'] = 'string';
+$vartype['file_prev_offset'] = 'intSign';
+$vartype['file_next_offset'] = 'intSign';
 $vartype['comments_offset'] = 'int';
 $vartype['comments_thresold'] = 'int';
 $vartype['comments_parentId'] = '+int';
-$vartype['comments_sort_mode'] = '+char';  // TODO: only allow valid field names and order here!
+$vartype['thread_sort_mode'] = '+char';  // TODO: only allow valid field names and order here!
+$vartype['thread_style'] = '+char';  // TODO: only allow valid field names and order here!
+$vartype['comments_per_page'] = '+int';
 $vartype['topics_offset'] = 'int';
 $vartype['topics_sort_mode'] = '+char';  // TODO: only allow valid field names and order here!
 $vartype['priority'] = 'int';
@@ -139,7 +207,7 @@ $vartype['edit_mode'] = 'char';
 $vartype['find'] = 'string';
 $vartype['topic_find'] = 'string';
 $vartype['initial'] = 'char';
-$vartype['username'] = 'string';
+$vartype['username'] = '+string';
 $vartype['realName'] = 'string';
 $vartype['homePage'] = 'string';
 $vartype['to'] = 'stringlist';
@@ -150,6 +218,7 @@ $vartype['name'] = 'string';
 $vartype['reqId'] = '+hash';
 $vartype['days'] = '+int';
 $vartype['max'] = '+int';
+$vartype['maxRecords'] = '+int';
 $vartype['numrows'] = '+int';
 $vartype['rows'] = '+int';
 $vartype['cols'] = '+int';
@@ -161,7 +230,6 @@ $vartype['user'] = '+string'; // remind password page
 $vartype['remind'] = 'string'; // remind password page
 $vartype['url'] = 'url';
 $vartype['game'] = 'string'; // from games
-$vartype['username'] = 'login'; // from games
 // galaxia
 $vartype['aid'] = '+int';
 $vartype['description'] = 'string';
@@ -175,21 +243,10 @@ $vartype['rolename'] = 'char';
 $vartype['type'] = 'string';
 $vartype['userole'] = 'int';
 $vartype['focus'] = 'string';
-
-
-// if we get an error while reading language from prefs, assume the db
-// is not yet set up and give a message
-$rc = @$tikilib->getOne( "select `value` from `tiki_preferences` where `name`=?",array("language"),false);
-if (!$rc) {
-	print "<html><head><title>Site not available</title></head><body><center><br />";
-	print "<b>Notice: this site is currently unavailable.<br /><br />Please try again later or contact the admin.</b></center></body></html>";
-	die();
-}
-
-$language = $tikilib->get_preference('language', 'en');// varcheck use tra
+$vartype['ver'] = 'dotvars'; // filename hash for drawlib + rss type for rsslib
 
 function varcheck($array) {
-  global $patterns, $vartype;
+  global $patterns, $vartype, $prefs;
   if (isset($array) and is_array($array)) {
     foreach ($array as $rq=>$rv) {
 	  // check if the variable name is allowed
@@ -197,19 +254,15 @@ function varcheck($array) {
         //die(tra("Invalid variable name : "). htmlspecialchars($rq));
       } elseif (isset($vartype["$rq"])) {
       	// variable allowed to be empty?
-    	if ('+'==substr($vartype[$rq],0,1)) {
-/*      		if ($rv == "") {
-	        	// TODO: better output!
-				print "<html><head><title>".tra("An error occurred.")."</title></head><body><center><br />";
-				print "<b>".tra("An error occurred.")."</b><br /><br /></center>";
-				print tra("Notice: this variable may not be empty:")." <font color='red'>$rq</font></body></html>";
-				die;
+      	if ('+'==substr($vartype[$rq],0,1)) {
+      		if ($rv == "") {
+			return(tra("Notice: this variable may not be empty:")." <font color='red'>$rq</font>");
       		}
-*/
       		// remove + from type
       		$vartype[$rq]=substr($vartype[$rq],1);
       	}
       	// expand arrays:
+				// TODO: handle return value
         if (is_array($rv)) {
           varcheck($rv);
         // check single parameters:
@@ -221,90 +274,73 @@ function varcheck($array) {
 	          or ($vartype["$rq"] == 'char') and !preg_match($patterns['char'],$rv)
 	          or ($vartype["$rq"] == 'hash') and !preg_match($patterns['hash'],$rv)
 	          or ($vartype["$rq"] == 'string') and !preg_match($patterns['string'],$rv)
-	          or ($vartype["$rq"] == 'stringlist') and !preg_match($patterns['stringlist'],$rv))
+	          or ($vartype["$rq"] == 'stringlist') and !preg_match($patterns['stringlist'],$rv)
+	          or ($vartype["$rq"] == 'dotvars') and !preg_match($patterns['dotvars'],$rv))
 	        {
-	        	// TODO: better output!
-				print "<html><head><title>".tra("An error occurred.")."</title></head><body><center><br />";
-				print "<b>".tra("An error occurred.")."</b><br /><br /></center>";
-				print tra("Notice: invalid variable value:")." $rq = <font color='red'>".htmlspecialchars($rv)."</font></body></html>";
-				die;
+						return(tra("Notice: invalid variable value:")." $rq = <font color='red'>".htmlspecialchars($rv)."</font>");
 	        }
         }
       }
     } // foreach
   }
 } // varcheck($array)
-varcheck($_REQUEST);
+
+$varcheck_errors=varcheck($_REQUEST);
 
 // rebuild $_REQUEST after sanity check
 unset($_REQUEST);
 unset($_COOKIE['offset']);
-$_REQUEST = array_merge($_COOKIE, $_POST, $_GET, $_ENV, $_SERVER);
+$_REQUEST = array_merge($_COOKIE, $_GET, $_POST, $_ENV, $_SERVER);
 if (!empty($_REQUEST['highlight'])) {
 	if (is_array($_REQUEST['highlight'])) $_REQUEST['highlight'] = '';
 	$_REQUEST['highlight'] = htmlspecialchars($_REQUEST['highlight']);
+	// Convert back sanitization tags into real tags to avoid them to be displayed
+	$_REQUEST['highlight'] = str_replace('&lt;x&gt;', '<x>', $_REQUEST['highlight']);
 }
 // ---------------------------------------------------------------------
 if (isset($_SERVER["REQUEST_URI"])) {
   ini_set('session.cookie_path', str_replace( "\\", "/", dirname($_SERVER["REQUEST_URI"])));
 }
 
-// set session lifetime
-$session_lifetime = $tikilib->get_preference('session_lifetime','0');
-if ($session_lifetime > 0) {
-	ini_set('session.gc_maxlifetime',$session_lifetime*60);
+if (!isset($_SERVER['QUERY_STRING'])) {
+	$_SERVER['QUERY_STRING'] = '';
+}
+if (empty($_SERVER['REQUEST_URI'])) {
+	$_SERVER['REQUEST_URI'] = $_SERVER['PHP_SELF'] . '?' . $_SERVER['QUERY_STRING'];
+}
+if (empty($_SERVER['SERVER_NAME'])) {
+	$_SERVER['SERVER_NAME'] = $_SERVER['HTTP_HOST'];
 }
 
-// is session data  stored in DB or in filesystem?
-$session_db = $tikilib->get_preference('session_db','n');
-if ($session_db == 'y') {
-	include('db/local.php');
-	$ADODB_SESSION_DRIVER=$db_tiki;
-	$ADODB_SESSION_CONNECT=$host_tiki;
-	$ADODB_SESSION_USER=$user_tiki;
-	$ADODB_SESSION_PWD=$pass_tiki;
-	$ADODB_SESSION_DB=$dbs_tiki;
-	unset($db_tiki);
-	unset($host_tiki);
-	unset($user_tiki);
-	unset($pass_tiki);
-	unset($dbs_tiki);
-	ini_set('session.save_handler','user');
-	include('session/adodb-session.php');
-}
-
-if ( $tikilib->get_preference('sessions_silent','disabled')=='disabled' or !empty($_COOKIE) ) {
-	// enabing silent sessions mean a session is only started when a cookie is presented
-	session_start();
-}
 
 // in the case of tikis on same domain we have to distinguish the realm
 // changed cookie and session variable name by a name made with siteTitle 
-$cookie_site = ereg_replace("[^a-zA-Z0-9]", "", $tikilib->get_preference('cookie_name','tikiwiki'));
+$cookie_site = ereg_replace("[^a-zA-Z0-9]", "", $prefs['cookie_name']);
 $user_cookie_site = 'tiki-user-'.$cookie_site;
 
-// Check if the user had a session before we assign one
-$user_had_existing_session = isset( $_SESSION["$user_cookie_site"] );
-
-// check if the remember me feature is enabled
-$rememberme = $tikilib->get_preference('rememberme', 'disabled');
-
 // if remember me is enabled, check for cookie where auth hash is stored
 // user gets logged in as the first user in the db with a matching hash
-if (($rememberme != 'disabled') 
+if (($prefs['rememberme'] != 'disabled') 
 	and (isset($_COOKIE["$user_cookie_site"])) 
 	and (!isset($user) and !isset($_SESSION["$user_cookie_site"]))) {
-	$user = $userlib->get_user_by_cookie($_COOKIE["$user_cookie_site"]);
+	if ($prefs['feature_intertiki'] == 'y' and !empty($prefs['feature_intertiki_mymaster']) and $prefs['feature_intertiki_sharedcookie'] == 'y') {
+		$rpcauth = $userlib->get_remote_user_by_cookie($_COOKIE["$user_cookie_site"]);
+		if (is_object($rpcauth)) {
+			$response_value = $rpcauth->value();
+			if (is_object($response_value))  {
+			$user = $response_value->scalarval();
+			}
+		}
+	} else {
+		$user = $userlib->get_user_by_cookie($_COOKIE["$user_cookie_site"]);
+	}
 	if ($user) {
 		$_SESSION["$user_cookie_site"] = $user;
 	}
 }
 
-// check what auth metod is selected. default is for the 'tiki' to auth users
-$auth_method = $tikilib->get_preference('auth_method', 'tiki');
-
 // if the auth method is 'web site', look for the username in $_SERVER
-if (($auth_method == 'ws') and (isset($_SERVER['REMOTE_USER']))) {
+if (($prefs['auth_method'] == 'ws') and (isset($_SERVER['REMOTE_USER']))) {
 	if ($userlib->user_exists($_SERVER['REMOTE_USER'])) {
 		$_SESSION["$user_cookie_site"] = $_SERVER['REMOTE_USER'];
 	} elseif ($userlib->user_exists(str_replace("\\\\", "\\",$_SERVER['REMOTE_USER']))) {
@@ -316,16 +352,40 @@ if (($auth_method == 'ws') and (isset($_SERVER['REMOTE_USER']))) {
 	}																						 
 }
 
+// check if phpCAS mods is installed 
+if (is_file('lib/phpcas/source/CAS/CAS.php')) {
+	$phpcas_enabled = 'y';
+} else {
+	$phpcas_enabled = 'n';
+}
+
+// Check for Shibboleth Login
+if ($prefs['auth_method'] == 'shib' and isset($_SERVER['REMOTE_USER'])){
+	// Validate the user (if not created create it)
+	if($userlib->validate_user($_SERVER['REMOTE_USER'],"","","")){
+		$_SESSION["$user_cookie_site"] = $_SERVER['REMOTE_USER'];
+	}
+}
+
 // if the username is already saved in the session, pull it from there
 if (isset($_SESSION["$user_cookie_site"])) {
 	$user = $_SESSION["$user_cookie_site"];
 
-	// web authorized users don't log in normally, so we will update their lastlogin here 
-	//  if we made a new session for them
-        if ( $auth_method == 'ws' && $user_had_existing_session == false )
-        {
-                $userlib->update_lastlogin( $user );
-        }
+	// There could be a case where the session contains a user that doesn't exists in this tiki
+	// or that has never used the login step in this tiki.
+	// Example : If using the same PHP SESSION cookies for more than one tiki.
+	$user_details = $userlib->get_user_details($user);
+	if ( ! is_array($user_details) || ! is_array($user_details['info']) || (int)$user_details['info']['lastLogin'] <= 0 ) {
+		global $cachelib;
+		require_once("lib/cache/cachelib.php");
+		$cachelib->invalidate('user_details_'.$user);
+		$user_details = $userlib->get_user_details($user);
+		if ( ! is_array($user_details) || ! is_array($user_details['info'])) {
+			$user = NULL;
+		}
+	}
+	unset($user_details);
+
 } else {
 	$user = NULL;
 	
@@ -357,7 +417,7 @@ if (isset($_SESSION["$user_cookie_site"])) {
 
 // --------------------------------------------------------------
 
-if (isset($_REQUEST['highlight']) || (isset($feature_referer_highlight) && $feature_referer_highlight == 'y') ) {
+if (isset($_REQUEST['highlight']) || (isset($prefs['feature_referer_highlight']) && $prefs['feature_referer_highlight'] == 'y') ) {
   $smarty->load_filter('output','highlight');
 }
 
@@ -387,7 +447,7 @@ else {
         }
         if ($len == '')
             return substr($str, $s);
-        else
+        else {
             for ($e = $s; $len > 0; --$len) {//found the real end
                 if ($e >= $limit)
                     break;
@@ -400,6 +460,7 @@ else {
                        }
             }
         return substr($str, $s, $e - $s);
+		}
     }
 }
 
@@ -416,6 +477,7 @@ if(!$cachelib->isCached("allperms")) {
 $allperms = $allperms["data"];
 
 //Initializes permissions
+
 foreach ($allperms as $vperm) {
 	$perm = $vperm["permName"];
 	$$perm = 'n';
@@ -424,220 +486,29 @@ foreach ($allperms as $vperm) {
 }
 
 // Permissions
-// Get group permissions here
-$perms = $userlib->get_user_permissions($user);
-foreach ($perms as $perm) {
-    //print("Asignando permiso global : $perm<br />");
-    $smarty->assign("$perm", 'y');
-
-    $$perm = 'y';
-}
-
-// If the user can admin file galleries then assign all the file galleries permissions
-if ($tiki_p_admin_file_galleries == 'y') {
-    $perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'file galleries');
-
-    foreach ($perms["data"] as $perm) {
-        $perm = $perm["permName"];
-
-        $smarty->assign("$perm", 'y');
-        $$perm = 'y';
-    }
-}
-
-if ($tiki_p_admin_workflow == 'y') {
-    $perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'workflow');
-
-    foreach ($perms["data"] as $perm) {
-        $perm = $perm["permName"];
-
-        $smarty->assign("$perm", 'y');
-        $$perm = 'y';
-    }
-}
-
-if ($tiki_p_admin_directory == 'y') {
-    $perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'directory');
-
-    foreach ($perms["data"] as $perm) {
-        $perm = $perm["permName"];
-
-        $smarty->assign("$perm", 'y');
-        $$perm = 'y';
-    }
-}
-
-if ($tiki_p_admin_charts == 'y') {
-    $perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'charts');
-
-    foreach ($perms["data"] as $perm) {
-        $perm = $perm["permName"];
-
-        $smarty->assign("$perm", 'y');
-        $$perm = 'y';
-    }
-}
-
-if ($tiki_p_blog_admin == 'y') {
-    $perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'blogs');
-
-    foreach ($perms["data"] as $perm) {
-        $perm = $perm["permName"];
-
-        $smarty->assign("$perm", 'y');
-        $$perm = 'y';
-    }
-}
-
-if ($tiki_p_admin_trackers == 'y') {
-    $perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'trackers');
-
-    foreach ($perms["data"] as $perm) {
-        $perm = $perm["permName"];
-
-        $smarty->assign("$perm", 'y');
-        $$perm = 'y';
-    }
-}
-
-if ($tiki_p_admin_galleries == 'y') {
-    $perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'image galleries');
-
-    foreach ($perms["data"] as $perm) {
-        $perm = $perm["permName"];
-
-        $smarty->assign("$perm", 'y');
-        $$perm = 'y';
-    }
-}
-
-if ($tiki_p_admin_forum == 'y') {
-    $perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'forums');
-
-    foreach ($perms["data"] as $perm) {
-        $perm = $perm["permName"];
-
-        $smarty->assign("$perm", 'y');
-        $$perm = 'y';
-    }
-}
-
-if ($tiki_p_admin_wiki == 'y') {
-    $perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'wiki');
-
-    foreach ($perms["data"] as $perm) {
-        $perm = $perm["permName"];
-
-        $smarty->assign("$perm", 'y');
-        $$perm = 'y';
-    }
-}
-
-if ($tiki_p_admin_faqs == 'y') {
-    $perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'faqs');
-
-    foreach ($perms["data"] as $perm) {
-        $perm = $perm["permName"];
-
-        $smarty->assign("$perm", 'y');
-        $$perm = 'y';
-    }
-}
-
-if ($tiki_p_admin_shoutbox == 'y') {
-    $perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'shoutbox');
-
-    foreach ($perms["data"] as $perm) {
-        $perm = $perm["permName"];
-
-        $smarty->assign("$perm", 'y');
-        $$perm = 'y';
-    }
-}
-
-if ($tiki_p_admin_quizzes == 'y') {
-    $perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'quizzes');
-
-    foreach ($perms["data"] as $perm) {
-        $perm = $perm["permName"];
-
-        $smarty->assign("$perm", 'y');
-        $$perm = 'y';
-    }
-}
-
-if ($tiki_p_admin_calendar == 'y') {
-    $perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'calendar');
-
-    foreach ($perms["data"] as $perm) {
-        $perm = $perm["permName"];
-
-        $smarty->assign("$perm", 'y');
-        $$perm = 'y';
-    }
-}
-
-
-if ($tiki_p_admin_sheet == 'y') {
-    $perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'sheet');
-
-    foreach ($perms["data"] as $perm) {
-        $perm = $perm["permName"];
-
-        $smarty->assign("$perm", 'y');
-        $$perm = 'y';
-    }
-}
-
-
-if ($tiki_p_admin_cms == 'y') {
-    $perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'cms');
-
-    foreach ($perms["data"] as $perm) {
-        $perm = $perm["permName"];
-
-        $smarty->assign("$perm", 'y');
-        $$perm = 'y';
-    }
-
-
-    $perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'topics');
-
-    foreach ($perms["data"] as $perm) {
-        $perm = $perm["permName"];
-
-        $smarty->assign("$perm", 'y');
-        $$perm = 'y';
-    }
-}
-
-//Gives admins all permissions
-if ($user == 'admin' || ($user && $userlib->user_has_permission($user, 'tiki_p_admin'))) {
+if ($user == 'admin' || ($user && $userlib->user_has_permission($user, 'tiki_p_admin'))) {//Gives admins all permissions
 	foreach ($allperms as $vperm) {
-		$perm = $vperm["permName"];
+		$perm = $vperm['permName'];
 		$$perm = 'y';
-
-		$smarty->assign("$perm", 'y');
+		$smarty->assign($perm, 'y');
+	}
+} else {
+	$perms = $userlib->get_user_detailled_permissions($user);
+	foreach ($perms as $perm) {
+	    $smarty->assign($perm['permName'], 'y');
+	    $$perm['permName'] = 'y';
+		if ($perm['admin'] == 'y') { // assign all perms of the perm type
+			$ps = $userlib->get_permissions(0, -1, 'permName_desc', '', $perm['type']);
+			foreach ($ps['data'] as $perm) {
+				$$perm['permName'] = 'y';
+				$smarty->assign($perm['permName'], 'y');
+			}
+		}
 	}
 }
 
 unset($allperms);
 
-$tikiIndex = $tikilib->get_preference("tikiIndex", 'tiki-index.php');
-
-$style = $tikilib->get_preference("style", 'moreneat.css');
-if ($tikidomain and is_file("styles/$tikidomain/$style")) {
-	$style = "$tikidomain/$style";
-}
-$smarty->assign('style', $style);
-
-$slide_style = $tikilib->get_preference("slide_style", 'slidestyle.css');
-$smarty->assign('slide_style', $slide_style);
-
-$feature_userPreferences = $tikilib->get_preference("feature_userPreferences", 'n');
-$change_language = $tikilib->get_preference("change_language", 'y');
-$change_theme = $tikilib->get_preference("change_theme", 'y');
-
 // Fix IIS servers not setting what they should set (ay ay IIS, ay ay)
 if (!isset($_SERVER['QUERY_STRING']))
     $_SERVER['QUERY_STRING'] = '';
@@ -650,6 +521,7 @@ $smarty->assign("tikidomain", $tikidomain);
 
 // Debug console open/close
 $smarty->assign('debugconsole_style',
-    isset($_COOKIE["debugconsole"]) && ($_COOKIE["debugconsole"] == 'o') ? 'display:block;' : 'display:none;');
+	isset($_COOKIE["debugconsole"]) && ($_COOKIE["debugconsole"] == 'o') ? 'display:block;' : 'display:none;'
+);
 
 ?>
