@@ -1,14 +1,18 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-show_user_avatar.php,v 1.6.2.3 2007/03/02 12:23:27 luciash Exp $
+// $Id: /cvsroot/tikiwiki/tiki/tiki-show_user_avatar.php,v 1.10 2007-03-06 19:29:52 sylvieg Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 
-include_once("lib/init/initlib.php");
-include_once ("tiki-setup_base.php");
+require 'tiki-setup.php';
+if( $prefs['feature_userPreferences'] != 'y' ) {
+	$smarty->assign('msg', tra("This feature is disabled").": feature_userPreferences");
 
+	$smarty->display("error.tpl");
+	die;
+}
 include_once ('lib/userprefs/userprefslib.php');
 
 // application to display an image from the database with 
