@@ -1,17 +1,18 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-upload_image.php,v 1.31.2.16 2007/05/01 21:50:52 sylvieg Exp $
+// $Id: /cvsroot/tikiwiki/tiki/tiki-upload_image.php,v 1.46.2.1 2008-03-15 21:11:15 sylvieg Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 
 // Initialization
+$section = 'galleries';
 require_once ('tiki-setup.php');
-
+include_once ('lib/categories/categlib.php');
 include_once ('lib/imagegals/imagegallib.php');
 
-if ($feature_galleries != 'y') {
+if ($prefs['feature_galleries'] != 'y') {
 	$smarty->assign('msg', tra("This feature is disabled").": feature_galleries");
 
 	$smarty->display("error.tpl");
@@ -20,6 +21,7 @@ if ($feature_galleries != 'y') {
 
 // Now check permissions to access this page
 if ($tiki_p_upload_images != 'y' and !$tikilib->user_has_perm_on_object($user,$_REQUEST["galleryId"],"image gallery","tiki_p_upload_images") ) {
+	$smarty->assign('errortype', 401);
 	$smarty->assign('msg', tra("Permission denied you cannot upload images"));
 
 	$smarty->display("error.tpl");
@@ -71,6 +73,7 @@ if (isset($_REQUEST["upload"])) {
 	}
 
 	if ($tiki_p_upload_images != 'y') {
+		$smarty->assign('errortype', 401);
 		$smarty->assign('msg', tra("Permission denied you cannot upload images"));
 
 		$smarty->display("error.tpl");
@@ -87,6 +90,7 @@ if (isset($_REQUEST["upload"])) {
 
 	// Check the user to be admin or owner or the gallery is public
 	if ($tiki_p_admin_galleries != 'y' && (!$user || $user != $gal_info["user"]) && $gal_info["public"] != 'y') {
+		$smarty->assign('errortype', 401);
 		$smarty->assign('msg', tra("Permission denied you can upload images but not to this gallery"));
 
 		$smarty->display("error.tpl");
@@ -95,6 +99,9 @@ if (isset($_REQUEST["upload"])) {
 
 	$error_msg = '';
 
+	if (empty($user) && $prefs['feature_antibot'] == 'y' && (!isset($_SESSION['random_number']) || $_SESSION['random_number'] != $_REQUEST['antibotcode'])) {
+		$error_msg = tra('You have mistyped the anti-bot verification code; please try again.');
+	}
 	if (!empty($_REQUEST["url"])) {
 		// check URL. avoid uploading local files!
 		if(!preg_match('#http[s]?://#i',$_REQUEST["url"])) {
@@ -122,8 +129,8 @@ if (isset($_REQUEST["upload"])) {
 		// We process here file uploads
 		if (isset($_FILES['userfile1']) && !empty($_FILES['userfile1']['name'])) {
 			if (is_uploaded_file($_FILES['userfile1']['tmp_name'])) {
-			if (!empty($gal_match_regex)) {
-				if (!preg_match("/$gal_match_regex/", $_FILES['userfile1']['name'], $reqs)) {
+			if (!empty($prefs['gal_match_regex'])) {
+				if (!preg_match('/'.$prefs['gal_match_regex'].'/', $_FILES['userfile1']['name'], $reqs)) {
 					$smarty->assign('msg', tra('Invalid imagename (using filters for filenames)'));
 
 					$smarty->display("error.tpl");
@@ -131,8 +138,8 @@ if (isset($_REQUEST["upload"])) {
 				}
 			}
 
-			if (!empty($gal_nmatch_regex)) {
-				if (preg_match("/$gal_nmatch_regex/", $_FILES['userfile1']['name'], $reqs)) {
+			if (!empty($prefs['gal_nmatch_regex'])) {
+				if (preg_match('/'.$prefs['gal_nmatch_regex'].'/', $_FILES['userfile1']['name'], $reqs)) {
 					$smarty->assign('msg', tra('Invalid imagename (using filters for filenames)'));
 
 					$smarty->display("error.tpl");
@@ -168,7 +175,7 @@ if (isset($_REQUEST["upload"])) {
 
 			$file_name = $_FILES['userfile1']['name'];	
 			$file_tmp_name = $_FILES['userfile1']['tmp_name'];
-			$tmp_dest = $tmpDir . '/' . $file_name.'.tmp'; // add .tmp to not overwrite existing files (like index.php)
+			$tmp_dest = $prefs['tmpDir'] . '/' . $file_name.'.tmp'; // add .tmp to not overwrite existing files (like index.php)
 			if (!move_uploaded_file($file_tmp_name, $tmp_dest)) {
 				$smarty->assign('msg', tra('Errors detected'));
 				$smarty->display("error.tpl");
@@ -184,7 +191,7 @@ if (isset($_REQUEST["upload"])) {
 				$error_msg = tra('The uploaded file ist not recognized as a image');
 	        }
 		} else {
-			$error_msg = tra("cannot process upload");
+			$error_msg = $tikilib->uploaded_file_error($_FILES['userfile1']['error']);
 		}
 		}
 	}
@@ -217,7 +224,7 @@ if (isset($_REQUEST["upload"])) {
 	
 	$lat=NULL;
 	$lon=NULL;
-	if ($feature_maps == 'y') {
+	if ($prefs['feature_maps'] == 'y') {
 		if (isset($_REQUEST["lat"])) {
 			$lat = (float) $_REQUEST["lat"];
 			$smarty->assign('lat', $lat);
@@ -257,7 +264,7 @@ if (isset($_REQUEST["upload"])) {
 
 				// CHECK IF THIS TEMP IS WRITEABLE OR CHANGE THE PATH TO A WRITEABLE DIRECTORY
 				//$tmpfname = 'temp.jpg';
-				$tmpfname = tempnam($tmpDir, "TMPIMG");
+				$tmpfname = tempnam($prefs['tmpDir'], "TMPIMG");
 				imagejpeg($t, $tmpfname);
 				// Now read the information
 				$fp = fopen($tmpfname, "rb");
@@ -389,7 +396,7 @@ for ($i = 0; $i < $temp_max; $i++) {
 
 $smarty->assign_by_ref('galleries', $galleries["data"]);
 
-if($feature_maps == 'y' && isset($_REQUEST["galleryId"])) {
+if($prefs['feature_maps'] == 'y' && isset($_REQUEST["galleryId"])) {
 	$gal_info = $imagegallib->get_gallery($_REQUEST["galleryId"]);
 	if ($gal_info['geographic'] == 'y') {
 		$smarty->assign('geogallery', 'y');
@@ -404,7 +411,6 @@ $cat_type = 'image';
 $cat_objid = '0';
 include_once ("categorize_list.php");
 
-$section = 'galleries';
 include_once ('tiki-section_options.php');
 
 $smarty->assign("max_img_upload_size", $imagegallib->max_img_upload_size());
