@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-view_chart_item.php,v 1.10.2.2 2007/03/02 12:23:21 luciash Exp $
+// $Id: /cvsroot/tikiwiki/tiki/tiki-view_chart_item.php,v 1.14 2007-10-12 07:55:33 nyloth Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -10,7 +10,7 @@ require_once ('tiki-setup.php');
 include_once ('lib/charts/chartlib.php');
 
 //xdebug_start_profiling();
-if ($feature_charts != 'y') {
+if ($prefs['feature_charts'] != 'y') {
 	$smarty->assign('msg', tra("This feature is disabled").": feature_charts");
 
 	$smarty->display("error.tpl");
